%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: bithe.def
%      Author: Oliver Corff
%        Date: December 1st, 2001
%     Version: 0.0 (Skeleton!)
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: Conventional Labels, litteral numbering and date,
%%  %	       given in Manju (Bithe)
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
%
% The caption names are defined here.
%
\def\captionsbicig{%
	\def\prefacename	{}
	%\def\prefacename	{}
	\def\refname		{}
	\def\abstractname	{}
	\def\bibname		{num zuii}
	\def\chaptername	{}
	\def\appendixname	{}
	\def\contentsname	{garcag}
	%\def\contentsname	{}
	\def\listfigurename	{zirug-un? afaha}
	\def\listtablename	{kuisunukdu-yin? afaha}
	\def\indexname		{}
	\def\figurename		{}
	\def\tablename		{}
	\def\partname		{anggi}
	\def\enclname		{}
	\def\ccname		{}
	\def\headtoname		{}
	\def\pagename		{}
	\def\seename		{}
	\def\alsoname		{}%
}
\newcommand{\BitheToday}{%
	\number\year\space aniya-i\space
	\number\month
%%  	\ifcase\month%
%%  	\or nigeduger%			January
%%  	\or xuyadugar%			February
%%  	\or gurbadugar%			March
%%  	\or duirbeduger%		April
%%  	\or tabdugar%			May
%%  	\or zirugadugar%		June
%%  	\or duludugar%			July
%%  	\or naimdugar%			August
%%  	\or isuduger%			September
%%  	\or arbadugar%			Oktober
%%  	\or arban nigeduger%		November
%%  	\or arban xuyadugar\fi%		December
	\space biya-i\space\number\day}
%
%
%%  \newcommand{\uisuk}[1]{{\mnr\ifcase#1%
%%  	\or A\or B\or W\or G\or D\or E\or \"E\or J%
%%  	\or Z\or I\or K\or L\or M\or N\or O\or \"O%
%%  	\or P\or R\or S\or T\or U\or \"U\or F\or X%
%%  	\or C\or Q\or {\Sh}\or \Qh\or \"A\or \Yu\or \Ya%
%%  		\else\@ctrerr\fi}}%
%%  %
%%  \newcommand{\buseg}[1]{{\mnr\ifcase#1%
%%  	\or a\or b\or w\or g\or d\or e\or \"e\or j%
%%  	\or z\or i\or k\or l\or m\or n\or o\or \"o%
%%  	\or p\or r\or s\or t\or u\or \"u\or f\or x%
%%  	\or c\or q\or {\sh}\or \qh\or \"a\or \yu\or \ya%
%%  		\else\@ctrerr\fi}}%
