% Copyright 2006 Konstantin Korikov <lostclus@ua.fm>
%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2003/12/01 or later.
%
% This work has the LPPL maintenance status "maintained".
% 
% This Current Maintainer of this work is Konstantin Korikov.
%
% This work consists of all files listed in manifest.txt.
%

%
% This is automaticaly generated file, do not edit it.
%

\ProvidesFile{eskdukrainian.def}[2010/01/17 v0.98 Language File]

\newcommand{\ESKDcolumnIVname}{%
  \cyr\CYRL\cyri\cyrt.}
\newcommand{\ESKDcolumnVname}{%
  \cyr\CYRM\cyra\cyrs\cyra}
\newcommand{\ESKDcolumnVIname}{%
  \cyr\CYRM\cyra\cyrs\cyrsh\cyrt\cyra\cyrb}
\newcommand{\ESKDcolumnVIIname}{%
  \cyr\CYRA\cyrr\cyrk\cyru\cyrsh}
\newcommand{\ESKDcolumnVIItwosideName}{%
  \cyr\CYRS\cyrt\cyro\cyrr.}
\newcommand{\ESKDcolumnVIIIname}{%
  \cyr\CYRA\cyrr\cyrk\cyru\cyrsh\cyrii\cyrv}
\newcommand{\ESKDcolumnVIIItwosideName}{%
  \cyr\CYRS\cyrt\cyro\cyrr\cyrii\cyrn\cyro\cyrk}
\newcommand{\ESKDcolumnXfIname}{%
  \cyr\CYRR\cyro\cyrz\cyrr\cyro\cyrb\cyri\cyrv}
\newcommand{\ESKDcolumnXfIIname}{%
  \cyr\CYRP\cyre\cyrr\cyre\cyrv\cyrii\cyrr\cyri\cyrv}
\newcommand{\ESKDcolumnXfIIIname}{%
  \cyr\CYRT. \cyrk\cyro\cyrn\cyrt\cyrr.}
\newcommand{\ESKDcolumnXfIVname}{}
\newcommand{\ESKDcolumnXfVname}{%
  \cyr\CYRN. \cyrk\cyro\cyrn\cyrt\cyrr.}
\newcommand{\ESKDcolumnXfVIname}{%
  \cyr\CYRZ\cyra\cyrt\cyrv\cyre\cyrr\cyrd\cyri\cyrv}
\newcommand{\ESKDcolumnXIVname}{%
  \cyr\CYRZ\cyrm.}
\newcommand{\ESKDcolumnXVname}{%
  \cyr\CYRL\cyri\cyrs\cyrt}
\newcommand{\ESKDcolumnXVIname}{%
  \No\ \cyr\cyrd\cyro\cyrk\cyru\cyrm.}
\newcommand{\ESKDcolumnXVIIname}{%
  \cyr\CYRP\cyrii\cyrd\cyrp.}
\newcommand{\ESKDcolumnXVIIIname}{%
  \cyr\CYRD\cyra\cyrt\cyra}
\newcommand{\ESKDcolumnXIXname}{%
  \cyr\CYRII\cyrn\cyrv. \No\ \cyro\cyrr\cyrii\cyrg.}
\newcommand{\ESKDcolumnXXname}{%
  \cyr\CYRP\cyrii\cyrd\cyrp. \cyrii\ \cyrd\cyra\cyrt\cyra}
\newcommand{\ESKDcolumnXXIname}{%
  \cyr\CYRV\cyrz\cyra\cyrm. \cyrii\cyrn\cyrv. \No}
\newcommand{\ESKDcolumnXXIIname}{%
  \cyr\CYRII\cyrn\cyrv. \No\ \cyrd\cyru\cyrb\cyrl.}
\newcommand{\ESKDcolumnXXIIIname}{%
  \cyr\CYRP\cyrii\cyrd\cyrp. \cyrii\ \cyrd\cyra\cyrt\cyra}
\newcommand{\ESKDcolumnXXIVname}{%
  \cyr\CYRS\cyrp\cyrr\cyra\cyrv. \No}
\newcommand{\ESKDcolumnXXVname}{%
  \cyr\CYRP\cyre\cyrr\cyrsh. \cyrz\cyra\cyrs\cyrt.}
\newcommand{\ESKDcolumnXXXIname}{%
  \cyr\CYRK\cyro\cyrp\cyrii\cyryu\cyrv\cyra\cyrv}
\@namedef{ESKDa0FormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \CYRA{}0}
\@namedef{ESKDa1FormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \CYRA{}1}
\@namedef{ESKDa2FormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \CYRA{}2}
\@namedef{ESKDa3FormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \CYRA{}3}
\@namedef{ESKDa4FormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \CYRA{}4}
\@namedef{ESKDemptyFormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \ \ \ }
\newcommand{\ESKDcolumnXXXIIIname}{%
  \cyr\CYRZ\cyro\cyrn\cyra}

\newcommand{\ESKDagreedName}{%
  \cyr\CYRP\cyro\cyrg\cyro\cyrd\cyrzh\cyre\cyrn\cyro}
\newcommand{\ESKDapprovingName}{%
  \cyr\CYRZ\cyra\cyrt\cyrv\cyre\cyrr\cyrd\cyrzh\cyru\cyryu}
\newcommand{\ESKDapprovedName}{%
  \cyr\CYRZ\cyra\cyrt\cyrv\cyre\cyrr\cyrd\cyrzh\cyre\cyrn\cyro}
\newcommand{\ESKDapprovingSheetName}{%
  \cyr\CYRL\cyri\cyrs\cyrt\ %
  \cyrz\cyra\cyrt\cyrv\cyre\cyrr\cyrd\cyrzh\cyre\cyrn\cyrn\cyrya}

\newlength{\ESKDexplanWidth}
\setlength{\ESKDexplanWidth}{1.5em}

\addto\captionsukrainian{%
  \def\tablename{{\cyr\CYRT\cyra\cyrb\cyrl\cyri\cyrc\cyrya}}%
  \def\figurename{{\cyr\CYRR\cyri\cyrs\cyru\cyrn\cyro\cyrk}}%
  \def\refname{{\cyr\CYRP\cyre\cyrr\cyre\cyrl\cyrii\cyrk\ 
    \cyrp\cyro\cyrs\cyri\cyrl\cyra\cyrn\cyrsftsn}}}

\newcommand{\ESKDspecColumnIname}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt}
\newcommand{\ESKDspecColumnIIname}{%
  \cyr\CYRZ\cyro\cyrn\cyra}
\newcommand{\ESKDspecColumnIIIname}{%
  \cyr\CYRP\cyro\cyrz.}
\newcommand{\ESKDspecColumnIVname}{%
  \cyr\CYRP\cyro\cyrz\cyrn\cyra\cyrch\cyre\cyrn\cyrn\cyrya}
\newcommand{\ESKDspecColumnVname}{%
  \cyr\CYRN\cyra\cyrishrt\cyrm\cyre\cyrn\cyru\cyrv\cyra\cyrn\cyrn\cyrya}
\newcommand{\ESKDspecColumnVIname}{%
  \cyr\CYRK\cyrii\cyrl\cyrsftsn\cyrk.}
\newcommand{\ESKDspecColumnVIIname}{%
  \cyr\CYRP\cyrr\cyri\cyrm\cyrii\cyrt\cyrk\cyra}

\newcommand{\ESKDspecIIcolumnIname}{\ESKDspecColumnIname}
\newcommand{\ESKDspecIIcolumnIIname}{\ESKDspecColumnIIname}
\newcommand{\ESKDspecIIcolumnIIIname}{\ESKDspecColumnIIIname}
\newcommand{\ESKDspecIIcolumnIVname}{\ESKDspecColumnIVname}
\newcommand{\ESKDspecIIcolumnVname}{\ESKDspecColumnVname}
\newcommand{\ESKDspecIIcolumnVIname}{\ESKDspecColumnVIname}
\newcommand{\ESKDspecIIcolumnVIIname}{%
  \cyr\CYRM\cyra\cyrs\cyra}
\newcommand{\ESKDspecIIcolumnVIIIname}{%
  \cyr\CYRM\cyra\cyrt\cyre\cyrr\cyrii\cyra\cyrl}
\newcommand{\ESKDspecIIcolumnIXname}{\ESKDspecColumnVIIname}

\newcommand{\ESKDchangeSheetName}{%
  \cyr\CYRL\cyri\cyrs\cyrt\ %
  \cyrr\cyre\cyrie\cyrs\cyrt\cyrr\cyra\cyrc\cyri\cyryi\ %
  \cyrz\cyrm\cyrii\cyrn}
\newcommand{\ESKDchngColumnsIIhName}{%
  \cyr\CYRN\cyro\cyrm\cyre\cyrr\cyri\ \cyra\cyrr\cyrk\cyru\cyrsh\cyrii\cyrv\ %
  (\cyrs\cyrt\cyro\cyrr\cyrii\cyrn\cyro\cyrk)}
\newcommand{\ESKDchngColumnIIname}{%
  \cyr\cyrz\cyrm\cyrii\-\cyrn\cyre\-\cyrn\cyri\cyrh}
\newcommand{\ESKDchngColumnIIIname}{%
  \cyr\cyrz\cyra\-\cyrm\cyrii\-\cyrn\cyre\-\cyrn\cyri\cyrh}
\newcommand{\ESKDchngColumnIVname}{%
  \cyr\cyrn\cyro\-\cyrv\cyri\cyrh}
\newcommand{\ESKDchngColumnVname}{%
  \cyr\cyra\cyrn\cyru\-\cyrl\cyrsftsn\cyro\cyrv\cyra\-\cyrn\cyri\cyrh}
\newcommand{\ESKDchngColumnVIname}{%
  \cyr\CYRR\cyra\cyrz\cyro\cyrm\ \cyra\cyrr\cyrk\cyru\cyrsh\cyrii\cyrv\ %
  (\cyrs\cyrt\cyro\cyrr\cyrii\cyrn\cyro\cyrk) \cyrv\ \cyrd\cyro\cyrk\cyru\cyrm.}
\newcommand{\ESKDchngColumnVIIIname}{%
  \cyr\CYRV\cyrh\cyrii\cyrd\cyrn\cyri\cyrishrt\ \No\ %
  \cyrs\cyru\cyrp\cyrr\cyro\cyrv\cyrii\cyrd\cyrn\cyro\cyrg\cyro\ %
  \cyrd\cyro\cyrk\cyru\cyrm. \cyrii\ %
  \cyrd\cyra\cyrt\cyra}

\def\@Asbuk#1{\ifcase#1\or
  \CYRA\or\CYRB\or\CYRV\or\CYRG\or\CYRD\or\CYRE\or
  \CYRZH\or\CYRI\or
  \CYRK\or\CYRL\or\CYRM\or\CYRN\or\CYRP\or\CYRR\or
  \CYRS\or\CYRT\or\CYRU\or\CYRF\or\CYRH\or\CYRC\or
  \CYRSH\or\CYRSHCH\or\CYRYU\or
  \CYRYA\else{\@tempcnta \number #1\relax
      \advance\@tempcnta -24\relax
      \protect\number\@tempcnta}
  \fi}
\def\@asbuk#1{\ifcase#1\or
  \cyra\or\cyrb\or\cyrv\or\cyrg\or\cyrd\or\cyre\or
  \cyrzh\or\cyri\or
  \cyrk\or\cyrl\or\cyrm\or\cyrn\or\cyrp\or\cyrr\or
  \cyrs\or\cyrt\or\cyru\or\cyrf\or\cyrh\or\cyrc\or
  \cyrsh\or\cyrshch\or\cyryu\or
  \cyrya\else{\@tempcnta \number #1\relax
      \advance\@tempcnta -24\relax
      \protect\number\@tempcnta}
  \fi}

