%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: Xalx.def
%      Author: Oliver Corff
%        Date: November 1st, 1998
%     Version: 0.2
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: Conventional Labels, litteral numbering and date,
%	       given in Modern Mongolian (Xalx)
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
%
% The caption names are defined here.
%
\def\captionsxalx{%
	\def\prefacename	{{\mnr Or{\sh}il}}
	%\def\prefacename	{{\mnr "Omn"ox "ug}}
	\def\refname		{{\mnr A{\sh}iglasan nom}}
	\def\abstractname	{{\mnr Towqlol}}
	\def\bibname		{{\mnr Nom z"u"i}}
	\def\chaptername	{{\mnr B"ul"ag}}
	\def\appendixname	{{\mnr Xawsralt}}
	\def\contentsname	{{\mnr Garqig}}
	%\def\contentsname	{{\mnr Aguulga}}
	\def\listfigurename	{{\mnr Zurgi"in jagsaalt}}
	\def\listtablename	{{\mnr X"usn"agti"in jagsaalt}}
	\def\indexname		{{\mnr B"ugd x"alx"a"as}}
	\def\figurename		{{\mnr Zurag}}
	\def\tablename		{{\mnr X"usn"agt}}
	\def\partname		{{\mnr X"as"ag}}
	\def\enclname		{{\mnr Oruulax}}
	\def\ccname		{{\mnr }}
	\def\headtoname		{{\mnr }}
	\def\pagename		{{\mnr Xuudas}}
	\def\seename		{{\mnr "uzn"a "u"u}}
	\def\alsoname		{{\mnr m"on "uzn"a "u"u}}%
}
\newcommand{\XalxToday}{%
{\mnr\number\year\space ony\space\ifcase\month%
	\or n"agd"ug"a"ar%		Januar
	\or xo"erdugaar%		Februar
	\or gurawdugaar%		M"arz
	\or d"or"owd"ug"a"ar%		April
	\or tawdugaar%			Mai
	\or zurgaadugaar%		Juni
	\or doloodugaar%		Juli
	\or na"imdugaar%		August
	\or esd"ug"a"ar%		September
	\or arawdugaar%			Oktober
	\or arwan n"agd"ug"a"ar%	November
	\or arwan xo"erdugaar\fi%	Dezember
	\space saryn\space\number\day}}
%
%
\newcommand{\Useg}[1]{{\mnr\ifcase#1%
	\or A\or B\or W\or G\or D\or E\or \"E\or J%
	\or Z\or I\or K\or L\or M\or N\or O\or \"O%
	\or P\or R\or S\or T\or U\or \"U\or F\or X%
	\or C\or Q\or {\Sh}\or \Qh\or \"A\or \Yu\or \Ya%
		\else\@ctrerr\fi}}%
%
\newcommand{\useg}[1]{{\mnr\ifcase#1%
	\or a\or b\or w\or g\or d\or e\or \"e\or j%
	\or z\or i\or k\or l\or m\or n\or o\or \"o%
	\or p\or r\or s\or t\or u\or \"u\or f\or x%
	\or c\or q\or {\sh}\or \qh\or \"a\or \yu\or \ya%
		\else\@ctrerr\fi}}%
