\addlanguage{belarusian}{loadhyph-be.tex}{}{2}{2}
\addlanguage{bulgarian}{loadhyph-bg.tex}{}{2}{2}
\addlanguage{churchslavonic}{loadhyph-cu.tex}{}{1}{2}
\addlanguage{kazakh}{loadhyph-kk.tex}{}{2}{2}
\addlanguage{mongolian}{loadhyph-mn-cyrl.tex}{}{2}{2}
\addlanguage{mongolianlmc}{loadhyph-mn-cyrl-x-lmc.tex}{}{2}{2}
\addlanguage{russian}{loadhyph-ru.tex}{}{2}{2}
\addlanguage{serbian}{loadhyph-sr-latn.tex}{}{2}{2}
\addlanguage{serbianc}{loadhyph-sr-cyrl.tex}{}{2}{2}
\addlanguage{ukrainian}{loadhyph-uk.tex}{}{2}{2}
