%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: cpdbk.def
%      Author: Oliver Corff
%        Date: February 8th, 1998
%     Version: 0.3
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: DBK codepage definition
%
%        Note: This file forms part of the MonTeX package which
%              should always be distributed in complete form.
%
%              The code positions in this file were cross-checked
%              by Vladimir Volovich and are compatible in position
%              and name with those of the emerging T2 standard.
%
%              Thank you very much, Vladimir!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
\ProvidesFile{cpdbk.def}
   [1997/11/01 v0.1 Input encoding file for DBK encoding]
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
%
% Cyrillic Letters
%
\DeclareInputText{128}{\CYRA}
\DeclareInputText{129}{\CYRB}
\DeclareInputText{130}{\CYRV}
\DeclareInputText{131}{\CYRG}
\DeclareInputText{132}{\CYRD}
\DeclareInputText{133}{\CYRE}
\DeclareInputText{134}{\CYRYO}
\DeclareInputText{135}{\CYRZH}
\DeclareInputText{136}{\CYRZ}
\DeclareInputText{137}{\CYRI}
\DeclareInputText{139}{\CYRISHRT}
\DeclareInputText{140}{\CYRK}
\DeclareInputText{142}{\CYRL}
\DeclareInputText{143}{\CYRM}
\DeclareInputText{144}{\CYRN}
\DeclareInputText{145}{\CYRO}
\DeclareInputText{146}{\CYROTLD}
\DeclareInputText{147}{\CYRP}
\DeclareInputText{148}{\CYRR}
\DeclareInputText{149}{\CYRS}
\DeclareInputText{150}{\CYRT}
\DeclareInputText{151}{\CYRU}
\DeclareInputText{152}{\CYRY}
\DeclareInputText{153}{\CYRF}
\DeclareInputText{154}{\CYRH}
\DeclareInputText{155}{\CYRC}
\DeclareInputText{156}{\CYRCH}
\DeclareInputText{157}{\CYRSH}
\DeclareInputText{158}{\CYRSHCH}
\DeclareInputText{159}{\CYRHRDSN}
\DeclareInputText{160}{\CYRERY}
\DeclareInputText{161}{\CYRSFTSN}
\DeclareInputText{162}{\CYREREV}
\DeclareInputText{163}{\CYRYU}
\DeclareInputText{164}{\CYRYA}
\DeclareInputText{165}{\cyra}
\DeclareInputText{166}{\cyrb}
\DeclareInputText{167}{\cyrv}
\DeclareInputText{168}{\cyrg}
\DeclareInputText{169}{\cyrd}
\DeclareInputText{170}{\cyre}
\DeclareInputText{171}{\cyryo}
\DeclareInputText{172}{\cyrzh}
\DeclareInputText{173}{\cyrz}
\DeclareInputText{174}{\cyri}
\DeclareInputText{175}{\cyrishrt}
\DeclareInputText{225}{\cyrk}
\DeclareInputText{226}{\cyrl}
\DeclareInputText{227}{\cyrm}
\DeclareInputText{228}{\cyrn}
\DeclareInputText{229}{\cyro}
\DeclareInputText{230}{\cyrotld}
\DeclareInputText{231}{\cyrp}
\DeclareInputText{232}{\cyrr}
\DeclareInputText{233}{\cyrs}
\DeclareInputText{234}{\cyrt}
\DeclareInputText{235}{\cyru}
\DeclareInputText{236}{\cyry}
\DeclareInputText{237}{\cyrf}
\DeclareInputText{238}{\cyrh}
\DeclareInputText{239}{\cyrc}
\DeclareInputText{241}{\cyrch}
\DeclareInputText{242}{\cyrsh}
\DeclareInputText{243}{\cyrshch}
\DeclareInputText{244}{\cyrhrdsn}
\DeclareInputText{245}{\cyrery}
\DeclareInputText{246}{\cyrsftsn}
\DeclareInputText{247}{\cyrerev}
\DeclareInputText{248}{\cyryu}
\DeclareInputText{249}{\cyrya}
\endinput
%% 
%% End of file `cpdbk.def'.
