%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: cpmls.def
%      Author: Oliver Corff
%        Date: February 8th, 1998
%     Version: 0.3
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: MLS codepage definition
%
%        Note: This file forms part of the MonTeX package which
%              should always be distributed in complete form.
%
%              The code positions in this file were cross-checked
%              by Vladimir Volovich and are compatible in position
%              and name with those of the emerging T2 standard.
%
%              Thank you very much, Vladimir!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
\ProvidesFile{cpmls.def}
   [1997/11/01 v0.1 Input encoding file for MLS encoding]
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
%
%
% Umlaute etc.
%
\DeclareInputText{"081}{{\"u}}
\DeclareInputText{"084}{{\"a}}
\DeclareInputText{"089}{{\"e}}
\DeclareInputText{"08B}{{\"i}}
\DeclareInputText{"08E}{{\"A}}
\DeclareInputText{"094}{{\"o}}
\DeclareInputText{"099}{{\"O}}
\DeclareInputText{"09A}{{\"U}}
\DeclareInputText{"0AE}{\lgu}
\DeclareInputText{"0AF}{\rgu}
\DeclareInputText{"0E1}{{\ss}}
\DeclareInputText{"0E7}{{\g}}
\DeclareInputText{"0FF}{\nobreakspace}
%
%
% Cyrillic Letters
%
\DeclareInputText{"80}{\CYRB}
\DeclareInputText{"82}{\CYRD}
\DeclareInputText{"83}{\CYRYO}
\DeclareInputText{"85}{\CYRZH}
\DeclareInputText{"86}{\CYRZ}
\DeclareInputText{"87}{\CYRI}
\DeclareInputText{"88}{\CYRISHRT}
\DeclareInputText{"8A}{\CYRL}
\DeclareInputText{"8C}{\CYROTLD}
\DeclareInputText{"8D}{\CYRP}
\DeclareInputText{"8F}{\CYRU}
\DeclareInputText{"90}{\CYRF}
\DeclareInputText{"91}{\CYRC}
\DeclareInputText{"92}{\CYRCH}
\DeclareInputText{"93}{\CYRSH}
\DeclareInputText{"95}{\CYRSHCH}
\DeclareInputText{"96}{\CYRHRDSN}
\DeclareInputText{"97}{\CYRERY}
\DeclareInputText{"98}{\CYRSFTSN}
\DeclareInputText{"9B}{\CYREREV}
\DeclareInputText{"9C}{\CYRYU}
\DeclareInputText{"9D}{\CYRYA}
\DeclareInputText{"9E}{\cyrb}
\DeclareInputText{"9F}{\cyrw}
\DeclareInputText{"A0}{\cyrg}
\DeclareInputText{"A1}{\cyrd}
\DeclareInputText{"A2}{\cyrj}
\DeclareInputText{"A3}{\cyrz}
\DeclareInputText{"A4}{\cyri}
\DeclareInputText{"A5}{\cyrishrt}
\DeclareInputText{"A6}{\cyrk}
\DeclareInputText{"A7}{\cyrl}
\DeclareInputText{"A8}{\cyrm}
\DeclareInputText{"A9}{\cyrn}
\DeclareInputText{"AA}{\cyrotld}
\DeclareInputText{"AB}{\cyrp}
\DeclareInputText{"AC}{\cyrt}
\DeclareInputText{"AD}{\cyry}
\DeclareInputText{"B0}{\cyrf}
\DeclareInputText{"B1}{\cyrc}
\DeclareInputText{"B2}{\cyrch}
\DeclareInputText{"B4}{\cyrsh}
\DeclareInputText{"B5}{\cyrshch}
\DeclareInputText{"B6}{\cyrhrdsn}
\DeclareInputText{"B7}{\cyrery}
\DeclareInputText{"B8}{\cyrsftsn}
\DeclareInputText{"BD}{\cyrerev}
\DeclareInputText{"BE}{\cyryu}
\DeclareInputText{"C1}{\cyrya}
\DeclareInputText{"E2}{\CYRG}
%
%
% Bicig Letters
%
\DeclareInputText{"C2}{\titem}
\DeclareInputText{"C3}{\shud}
\DeclareInputText{"C5}{\secondaryshud}
\DeclareInputText{"C6}{\shilbe}
\DeclareInputText{"C7}{\gedes}
\DeclareInputText{"CF}{\secondarygedes}
\DeclareInputText{"D0}{\cegteishud}
\DeclareInputText{"D1}{\lewer}
\DeclareInputText{"D2}{\suuliinlewer}
\DeclareInputText{"D3}{\tertiarylewer}
\DeclareInputText{"D4}{\mewer}
\DeclareInputText{"D5}{\suuliinmewer}
\DeclareInputText{"D6}{\xewteeqix}
\DeclareInputText{"D7}{\dawxarcegtxewteeqix}
\DeclareInputText{"D8}{\halfnum}
\DeclareInputText{"DB}{\num}
\DeclareInputText{"DC}{\halfnumtgedes}
\DeclareInputText{"DD}{\numtaigedes}
\DeclareInputText{"DE}{\buruuxarsangedes}
\DeclareInputText{"DF}{\gedesteishilbe}
\DeclareInputText{"E0}{\erweeljinshilbe}
\DeclareInputText{"E3}{\secerweeljin}
\DeclareInputText{"E4}{\bosooshilbe}
\DeclareInputText{"E5}{\etgershilbe}
\DeclareInputText{"E6}{\zawj}
\DeclareInputText{"E8}{\suuliinzawj}
\DeclareInputText{"E9}{\dawxarcegtzawj}
\DeclareInputText{"EA}{\sereeewer}
\DeclareInputText{"EB}{\matgarshilbe}
\DeclareInputText{"EC}{\bituushilbe}
\DeclareInputText{"ED}{\secondaryqagt}
\DeclareInputText{"EE}{\qagt}
\DeclareInputText{"EF}{\secnumtdelbenqix}
\DeclareInputText{"F0}{\numtdelbenqix}
\DeclareInputText{"F1}{\secsertenqixtnum}
\DeclareInputText{"F2}{\sertenqixtnum}
\DeclareInputText{"F3}{\zadgaizardigt}
\DeclareInputText{"F4}{\bituuzardigt}
\DeclareInputText{"F5}{\malgaitaititem}
\DeclareInputText{"F6}{\suul}
\DeclareInputText{"F7}{\orxic}
\DeclareInputText{"F8}{\biodoisuul}
\DeclareInputText{"F9}{\bagodoisuul}
\DeclareInputText{"FA}{\nceg}
\DeclareInputText{"FB}{\gceg}
\DeclareInputText{"FC}{\ceg}
\DeclareInputText{"FD}{\dorwoljin}
%%
\endinput
%% 
%% End of file `cpmls.def'.
