%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: cpkoi.def
%      Author: Oliver Corff
%        Date: February 8th, 1998
%     Version: 0.3
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: KOI codepage definition
%
%        Note: This file forms part of the MonTeX package which
%              should always be distributed in complete form.
%
%              The code positions in this file were cross-checked
%              by Vladimir Volovich and are compatible in position
%              and name with those of the emerging T2 standard.
%
%              Thank you very much, Vladimir!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
\ProvidesFile{cpkoi.def}
   [1997/11/01 v0.1 Input encoding file for KOI encoding]
	\message{Attention; this one may be buggy, especially XATUU TEMDEG!}
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
%
% Cyrillic Letters
%
\DeclareInputText{"E1}{\CYRA}
\DeclareInputText{"E2}{\CYRB}
\DeclareInputText{"F7}{\CYRV}
\DeclareInputText{"E7}{\CYRG}
\DeclareInputText{"E4}{\CYRD}
\DeclareInputText{"E5}{\CYRE}
\DeclareInputText{"A4}{\CYRYO}
\DeclareInputText{"F6}{\CYRZH}
\DeclareInputText{"FA}{\CYRZ}
\DeclareInputText{"E9}{\CYRI}
\DeclareInputText{"EA}{\CYRISHRT}
\DeclareInputText{"EB}{\CYRK}
\DeclareInputText{"EC}{\CYRL}
\DeclareInputText{"ED}{\CYRM}
\DeclareInputText{"EE}{\CYRN}
\DeclareInputText{"EF}{\CYRO}
% \DeclareInputText{"  }{\CYROTLD} Not available in KOI!
\DeclareInputText{"F0}{\CYRP}
\DeclareInputText{"F2}{\CYRR}
\DeclareInputText{"F3}{\CYRS}
\DeclareInputText{"F4}{\CYRT}
\DeclareInputText{"F5}{\CYRU}
% \DeclareInputText{"  }{\CYRY} Not available in KOI!
\DeclareInputText{"E6}{\CYRF}
\DeclareInputText{"E8}{\CYRH}
% \DeclareInputText{"  }{\CYRHSHA} Not available in KOI!
\DeclareInputText{"E3}{\CYRC}
\DeclareInputText{"FE}{\CYRCH}
\DeclareInputText{"FB}{\CYRSH}
\DeclareInputText{"FD}{\CYRSHCH}
\DeclareInputText{"FF}{\CYRHRDSN}
\DeclareInputText{"F9}{\CYRERY}
\DeclareInputText{"F8}{\CYRSFTSN}
\DeclareInputText{"FC}{\CYREREV}
\DeclareInputText{"E0}{\CYRYA}
\DeclareInputText{"F1}{\CYRYU}

\DeclareInputText{"C1}{\cyra}
\DeclareInputText{"C2}{\cyrb}
\DeclareInputText{"D7}{\cyrv}
\DeclareInputText{"C7}{\cyrg}
\DeclareInputText{"C4}{\cyrd}
\DeclareInputText{"C5}{\cyre}
\DeclareInputText{"A3}{\cyryo}
\DeclareInputText{"D6}{\cyrzh}
\DeclareInputText{"DA}{\cyrz}
\DeclareInputText{"C9}{\cyri}
\DeclareInputText{"CA}{\cyrishrt}
\DeclareInputText{"CB}{\cyrk}
\DeclareInputText{"CC}{\cyrl}
\DeclareInputText{"CD}{\cyrm}
\DeclareInputText{"CE}{\cyrn}
\DeclareInputText{"CF}{\cyro}
% \DeclareInputText{"  }{\cyroe} Not available in KOI!
\DeclareInputText{"D0}{\cyrp}
\DeclareInputText{"D2}{\cyrr}
\DeclareInputText{"D3}{\cyrs}
\DeclareInputText{"D4}{\cyrt}
\DeclareInputText{"D5}{\cyru}
% \DeclareInputText{"  }{\cyrue} Not available in KOI!
\DeclareInputText{"C6}{\cyrf}
\DeclareInputText{"C8}{\cyrh}
% \DeclareInputText{"  }{\cyrhsha} Not available in KOI!
\DeclareInputText{"C3}{\cyrc}
\DeclareInputText{"DE}{\cyrch}
\DeclareInputText{"DB}{\cyrsh}
\DeclareInputText{"DD}{\cyrhch}
\DeclareInputText{"DF}{\cyrhrdsn}
\DeclareInputText{"D9}{\cyrery}
\DeclareInputText{"D8}{\cyrsftsn}
\DeclareInputText{"DC}{\cyrerev}
\DeclareInputText{"C0}{\cyryu}
\DeclareInputText{"D1}{\cyrya}
%
\endinput
%% 
%% End of file `cpkoi.def'.
