%%
%% This is file `lcywenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% lcyw.dtx  (with options: `LCYW')
%% 
%% This is a generated file.
%% 
%% Copyright (C) 2008 Vladimir Lidovski
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.3c
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
\ProvidesFile{lcywenc.def}
  [2008/04/15 v1.0 Cyrillic encoding definition file]
\def\cyrillicencoding{LCYW}         %for babel compatibility
\DeclareFontEncoding{LCYW}{}{}
\DeclareFontSubstitution{\LastDeclaredEncoding}{cmr}{m}{n}
\DeclareTextAccent{\"}{LCYW}{127}
\DeclareTextAccent{\'}{LCYW}{19}
\DeclareTextAccent{\.}{LCYW}{95}
\DeclareTextAccent{\=}{LCYW}{22}
\DeclareTextAccent{\^}{LCYW}{94}
\DeclareTextAccent{\`}{LCYW}{18}
\DeclareTextAccent{\~}{LCYW}{126}
\DeclareTextAccent{\H}{LCYW}{125}
\DeclareTextAccent{\u}{LCYW}{21}
\DeclareTextAccent{\v}{LCYW}{20}
\DeclareTextAccent{\r}{LCYW}{23}
\DeclareTextCommand{\b}{LCYW}[1]
   {\hmode@bgroup\o@lign{\relax#1\crcr\hidewidth\sh@ft{29}%
     \vbox to.2ex{\hbox{\char22}\vss}\hidewidth}\egroup}
\DeclareTextCommand{\c}{LCYW}[1]
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent24 #1%
    \else{\ooalign{\unhbox\z@\crcr\hidewidth\char24\hidewidth}}\fi}
\DeclareTextCommand{\d}{LCYW}[1]
   {\hmode@bgroup
    \o@lign{\relax#1\crcr\hidewidth\sh@ft{10}.\hidewidth}\egroup}
\DeclareTextSymbol{\AE}{LCYW}{29}
\DeclareTextSymbol{\OE}{LCYW}{30}
\DeclareTextSymbol{\O}{LCYW}{31}
\DeclareTextSymbol{\ae}{LCYW}{26}
\DeclareTextSymbol{\i}{LCYW}{16}
\DeclareTextSymbol{\j}{LCYW}{17}
\DeclareTextSymbol{\oe}{LCYW}{27}
\DeclareTextSymbol{\o}{LCYW}{28}
\DeclareTextSymbol{\ss}{LCYW}{25}
\DeclareTextSymbol{\textemdash}{LCYW}{124}
\DeclareTextSymbol{\textendash}{LCYW}{123}
\DeclareTextCommand{\textexclamdown}{LCYW}{!`}
\DeclareTextCommand{\textquestiondown}{LCYW}{?`}
\DeclareTextSymbol{\textquotedblleft}{LCYW}{92}
\DeclareTextSymbol{\textquotedblright}{LCYW}{`\"}
\DeclareTextSymbol{\textquoteleft}{LCYW}{`\`}
\DeclareTextSymbol{\textquoteright}{LCYW}{`\'}
\DeclareTextCommand{\L}{LCYW}
   {\leavevmode\setbox\z@\hbox{L}\hb@xt@\wd\z@{\hss\@xxxii L}}
\DeclareTextCommand{\l}{LCYW}
   {\hmode@bgroup\@xxxii l\egroup}
\DeclareTextCompositeCommand{\r}{LCYW}{A}
   {\leavevmode\setbox\z@\hbox{!}\dimen@\ht\z@\advance\dimen@-1ex%
    \rlap{\raise.67\dimen@\hbox{\char23}}A}
\DeclareTextCommand{\textdollar}{LCYW}{\hmode@bgroup
   \ifdim \fontdimen\@ne\font >\z@
      \slshape
   \else
      \upshape
   \fi
   \char`\$\egroup}
\DeclareTextCommand{\textsterling}{LCYW}{\hmode@bgroup
   \ifdim \fontdimen\@ne\font >\z@
      \itshape
   \else
      \fontshape{ui}\selectfont
   \fi
   \char`\$\egroup}
\DeclareTextComposite{\.}{LCYW}{i}{`\i}
\DeclareTextComposite{\.}{LCYW}{\i}{`\i}
\DeclareTextCompositeCommand{\`}{LCYW}{i}{\@tabacckludge`\i}
\DeclareTextCompositeCommand{\'}{LCYW}{i}{\@tabacckludge'\i}
\DeclareTextCompositeCommand{\^}{LCYW}{i}{\^\i}
\DeclareTextCompositeCommand{\"}{LCYW}{i}{\"\i}
\DeclareTextAccent{\U}{\LastDeclaredEncoding}{20}
\DeclareTextSymbol{\cyrdash}{\LastDeclaredEncoding}{124}
\DeclareTextSymbol{\textasciicircum}{\LastDeclaredEncoding}{94}
\DeclareTextSymbol{\textasciitilde}{\LastDeclaredEncoding}{126}
\DeclareTextSymbol{\textquotedbl}{\LastDeclaredEncoding}{34}
\DeclareTextSymbol{\guillemotleft}{\LastDeclaredEncoding}{60}
\DeclareTextSymbol{\guillemotright}{\LastDeclaredEncoding}{62}
\DeclareTextSymbol{\textnumero}{\LastDeclaredEncoding}{185}
\DeclareTextComposite{\.}{\LastDeclaredEncoding}{i}{`\i}
\DeclareTextSymbol{\CYRA}{\LastDeclaredEncoding}{192}
\DeclareTextSymbol{\cyra}{\LastDeclaredEncoding}{224}
\DeclareTextSymbol{\CYRB}{\LastDeclaredEncoding}{193}
\DeclareTextSymbol{\cyrb}{\LastDeclaredEncoding}{225}
\DeclareTextSymbol{\CYRV}{\LastDeclaredEncoding}{194}
\DeclareTextSymbol{\cyrv}{\LastDeclaredEncoding}{226}
\DeclareTextSymbol{\CYRG}{\LastDeclaredEncoding}{195}
\DeclareTextSymbol{\cyrg}{\LastDeclaredEncoding}{227}
\DeclareTextSymbol{\CYRD}{\LastDeclaredEncoding}{196}
\DeclareTextSymbol{\cyrd}{\LastDeclaredEncoding}{228}
\DeclareTextSymbol{\CYRE}{\LastDeclaredEncoding}{197}
\DeclareTextSymbol{\cyre}{\LastDeclaredEncoding}{229}
\DeclareTextSymbol{\CYRZH}{\LastDeclaredEncoding}{198}
\DeclareTextSymbol{\cyrzh}{\LastDeclaredEncoding}{230}
\DeclareTextSymbol{\CYRZ}{\LastDeclaredEncoding}{199}
\DeclareTextSymbol{\cyrz}{\LastDeclaredEncoding}{231}
\DeclareTextSymbol{\CYRI}{\LastDeclaredEncoding}{200}
\DeclareTextSymbol{\cyri}{\LastDeclaredEncoding}{232}
\DeclareTextSymbol{\CYRISHRT}{\LastDeclaredEncoding}{201}
\DeclareTextSymbol{\cyrishrt}{\LastDeclaredEncoding}{233}
\DeclareTextSymbol{\CYRK}{\LastDeclaredEncoding}{202}
\DeclareTextSymbol{\cyrk}{\LastDeclaredEncoding}{234}
\DeclareTextSymbol{\CYRL}{\LastDeclaredEncoding}{203}
\DeclareTextSymbol{\cyrl}{\LastDeclaredEncoding}{235}
\DeclareTextSymbol{\CYRM}{\LastDeclaredEncoding}{204}
\DeclareTextSymbol{\cyrm}{\LastDeclaredEncoding}{236}
\DeclareTextSymbol{\CYRN}{\LastDeclaredEncoding}{205}
\DeclareTextSymbol{\cyrn}{\LastDeclaredEncoding}{237}
\DeclareTextSymbol{\CYRO}{\LastDeclaredEncoding}{206}
\DeclareTextSymbol{\cyro}{\LastDeclaredEncoding}{238}
\DeclareTextSymbol{\CYRP}{\LastDeclaredEncoding}{207}
\DeclareTextSymbol{\cyrp}{\LastDeclaredEncoding}{239}
\DeclareTextSymbol{\CYRR}{\LastDeclaredEncoding}{208}
\DeclareTextSymbol{\cyrr}{\LastDeclaredEncoding}{240}
\DeclareTextSymbol{\CYRS}{\LastDeclaredEncoding}{209}
\DeclareTextSymbol{\cyrs}{\LastDeclaredEncoding}{241}
\DeclareTextSymbol{\CYRT}{\LastDeclaredEncoding}{210}
\DeclareTextSymbol{\cyrt}{\LastDeclaredEncoding}{242}
\DeclareTextSymbol{\CYRU}{\LastDeclaredEncoding}{211}
\DeclareTextSymbol{\cyru}{\LastDeclaredEncoding}{243}
\DeclareTextSymbol{\CYRF}{\LastDeclaredEncoding}{212}
\DeclareTextSymbol{\cyrf}{\LastDeclaredEncoding}{244}
\DeclareTextSymbol{\CYRH}{\LastDeclaredEncoding}{213}
\DeclareTextSymbol{\cyrh}{\LastDeclaredEncoding}{245}
\DeclareTextSymbol{\CYRC}{\LastDeclaredEncoding}{214}
\DeclareTextSymbol{\cyrc}{\LastDeclaredEncoding}{246}
\DeclareTextSymbol{\CYRCH}{\LastDeclaredEncoding}{215}
\DeclareTextSymbol{\cyrch}{\LastDeclaredEncoding}{247}
\DeclareTextSymbol{\CYRSH}{\LastDeclaredEncoding}{216}
\DeclareTextSymbol{\cyrsh}{\LastDeclaredEncoding}{248}
\DeclareTextSymbol{\CYRSHCH}{\LastDeclaredEncoding}{217}
\DeclareTextSymbol{\cyrshch}{\LastDeclaredEncoding}{249}
\DeclareTextSymbol{\CYRHRDSN}{\LastDeclaredEncoding}{218}
\DeclareTextSymbol{\cyrhrdsn}{\LastDeclaredEncoding}{250}
\DeclareTextSymbol{\CYRERY}{\LastDeclaredEncoding}{219}
\DeclareTextSymbol{\cyrery}{\LastDeclaredEncoding}{251}
\DeclareTextSymbol{\CYRSFTSN}{\LastDeclaredEncoding}{220}
\DeclareTextSymbol{\cyrsftsn}{\LastDeclaredEncoding}{252}
\DeclareTextSymbol{\CYREREV}{\LastDeclaredEncoding}{221}
\DeclareTextSymbol{\cyrerev}{\LastDeclaredEncoding}{253}
\DeclareTextSymbol{\CYRYU}{\LastDeclaredEncoding}{222}
\DeclareTextSymbol{\cyryu}{\LastDeclaredEncoding}{254}
\DeclareTextSymbol{\CYRYA}{\LastDeclaredEncoding}{223}
\DeclareTextSymbol{\cyrya}{\LastDeclaredEncoding}{255}
\DeclareTextSymbol{\CYRYO}{\LastDeclaredEncoding}{168}
\DeclareTextSymbol{\cyryo}{\LastDeclaredEncoding}{184}
\DeclareTextSymbol{\CYRII}{\LastDeclaredEncoding}{73}
\DeclareTextSymbol{\cyrii}{\LastDeclaredEncoding}{105}
\DeclareTextSymbol{\CYRJE}{\LastDeclaredEncoding}{74}
\DeclareTextSymbol{\cyrje}{\LastDeclaredEncoding}{106}
\DeclareTextSymbol{\CYRQ}{\LastDeclaredEncoding}{81}
\DeclareTextSymbol{\cyrq}{\LastDeclaredEncoding}{113}
\DeclareTextSymbol{\CYRW}{\LastDeclaredEncoding}{87}
\DeclareTextSymbol{\cyrw}{\LastDeclaredEncoding}{119}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\CYRE}{168}
\DeclareTextComposite{\"}{\LastDeclaredEncoding}{\cyre}{184}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\CYRI}{201}
\DeclareTextComposite{\U}{\LastDeclaredEncoding}{\cyri}{233}
\endinput
%%
%% End of file `lcywenc.def'.
