%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: cpctt.def
%      Author: Oliver Corff
%        Date: November 8th, 2001
%     Version: 0.4
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: CTT codepage definition
%
%        Note: This file forms part of the MonTeX package which
%              should always be distributed in complete form.
%
%              The code positions in this file were cross-checked
%              by Vladimir Volovich and are compatible in position
%              and name with those of the T2 standard.
%
%              Thank you very much, Vladimir!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
\ProvidesFile{cpctt.def}
   [1999/02/02 v0.2 Input encoding file for CTT encoding]
\NeedsTeXFormat{LaTeX2e}[1995/12/01]

\DeclareInputText{"AB}{\lgu}
\DeclareInputText{"BB}{\rgu}
%
\let\lgu\guillemotleft
\let\rgu\guillemotright
%
% Cyrillic Letters
%
\DeclareInputText{192}{\CYRA}
\DeclareInputText{193}{\CYRB}
\DeclareInputText{194}{\CYRV}
\DeclareInputText{195}{\CYRG}
\DeclareInputText{196}{\CYRD}
\DeclareInputText{197}{\CYRE}
\DeclareInputText{168}{\CYRYO}
\DeclareInputText{198}{\CYRZH}
\DeclareInputText{199}{\CYRZ}
\DeclareInputText{200}{\CYRI}
\DeclareInputText{201}{\CYRISHRT}
\DeclareInputText{202}{\CYRK}
\DeclareInputText{203}{\CYRL}
\DeclareInputText{204}{\CYRM}
\DeclareInputText{205}{\CYRN}
\DeclareInputText{206}{\CYRO}
\DeclareInputText{170}{\CYROTLD}
\DeclareInputText{207}{\CYRP}
\DeclareInputText{208}{\CYRR}
\DeclareInputText{209}{\CYRS}
\DeclareInputText{210}{\CYRT}
\DeclareInputText{211}{\CYRU}
\DeclareInputText{175}{\CYRY}
\DeclareInputText{212}{\CYRF}
\DeclareInputText{213}{\CYRH}
\DeclareInputText{214}{\CYRC}
\DeclareInputText{215}{\CYRCH}
\DeclareInputText{216}{\CYRSH}
\DeclareInputText{217}{\CYRSHCH}
\DeclareInputText{218}{\CYRHRDSN}
\DeclareInputText{219}{\CYRERY}
\DeclareInputText{220}{\CYRSFTSN}
\DeclareInputText{221}{\CYREREV}
\DeclareInputText{222}{\CYRYU}
\DeclareInputText{223}{\CYRYA}
%
\DeclareInputText{"E0}{\cyra}
\DeclareInputText{"E1}{\cyrb}
\DeclareInputText{"E2}{\cyrv}
\DeclareInputText{"E3}{\cyrg}
\DeclareInputText{"E4}{\cyrd}
\DeclareInputText{"E5}{\cyre}
\DeclareInputText{"B8}{\cyryo}
\DeclareInputText{"E6}{\cyrzh}
\DeclareInputText{"E7}{\cyrz}
\DeclareInputText{"E8}{\cyri}
\DeclareInputText{"E9}{\cyrishrt}
\DeclareInputText{"EA}{\cyrk}
\DeclareInputText{"EB}{\cyrl}
\DeclareInputText{"EC}{\cyrm}
\DeclareInputText{"ED}{\cyrn}
\DeclareInputText{"EE}{\cyro}
\DeclareInputText{"BA}{\cyrotld}
\DeclareInputText{"EF}{\cyrp}
\DeclareInputText{"F0}{\cyrr}
\DeclareInputText{"F1}{\cyrs}
\DeclareInputText{"F2}{\cyrt}
\DeclareInputText{"F3}{\cyru}
\DeclareInputText{"BF}{\cyry}
\DeclareInputText{"F4}{\cyrf}
\DeclareInputText{"F5}{\cyrh}
\DeclareInputText{"F6}{\cyrc}
\DeclareInputText{"F7}{\cyrch}
\DeclareInputText{"F8}{\cyrsh}
\DeclareInputText{"F9}{\cyrshch}
\DeclareInputText{"FA}{\cyrhrdsn}
\DeclareInputText{"FB}{\cyrery}
\DeclareInputText{"FC}{\cyrsftsn}
\DeclareInputText{"FD}{\cyrerev}
\DeclareInputText{"FE}{\cyryu}
\DeclareInputText{"FF}{\cyrya}
%
\endinput
%% 
%% End of file `cpctt.def'.
