%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: cpmnk.def
%      Author: Oliver Corff
%        Date: February 8th, 1998
%     Version: 0.3
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: MNK codepage definition
%
%        Note: This file forms part of the MonTeX package which
%              should always be distributed in complete form.
%
%              The code positions in this file were cross-checked
%              by Vladimir Volovich and are compatible in position
%              and name with those of the emerging T2 standard.
%
%              Thank you very much, Vladimir!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
\ProvidesFile{cpmnk.def}
   [1997/11/01 v0.1 Input encoding file for MNK encoding]
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
%
% Cyrillic Letters
%
\DeclareInputText{128}{\CYRA}
\DeclareInputText{129}{\CYRB}
\DeclareInputText{130}{\CYRV}
\DeclareInputText{131}{\CYRG}
\DeclareInputText{132}{\CYRD}
\DeclareInputText{133}{\CYRE}
\DeclareInputText{134}{\CYRYO}
\DeclareInputText{135}{\CYRZH}
\DeclareInputText{136}{\CYRZ}
\DeclareInputText{137}{\CYRI}
\DeclareInputText{138}{\CYRISHRT}
\DeclareInputText{139}{\CYRK}
\DeclareInputText{140}{\CYRL}
\DeclareInputText{141}{\CYRM}
\DeclareInputText{142}{\CYRN}
\DeclareInputText{143}{\CYRO}
\DeclareInputText{144}{\CYROTLD}
\DeclareInputText{145}{\CYRP}
\DeclareInputText{146}{\CYRR}
\DeclareInputText{147}{\CYRS}
\DeclareInputText{148}{\CYRT}
\DeclareInputText{149}{\CYRU}
\DeclareInputText{150}{\CYRY}
\DeclareInputText{151}{\CYRF}
\DeclareInputText{152}{\CYRH}
\DeclareInputText{153}{\CYRC}
\DeclareInputText{154}{\CYRCH}
\DeclareInputText{155}{\CYRSH}
\DeclareInputText{156}{\CYRSHCH}
\DeclareInputText{157}{\CYRHRDSN}
\DeclareInputText{158}{\CYRERY}
\DeclareInputText{159}{\CYRSFTSN}
\DeclareInputText{160}{\CYREREV}
\DeclareInputText{161}{\CYRYU}
\DeclareInputText{162}{\CYRYA}
\DeclareInputText{163}{\cyra}
\DeclareInputText{164}{\cyrb}
\DeclareInputText{165}{\cyrv}
\DeclareInputText{166}{\cyrg}
\DeclareInputText{167}{\cyrd}
\DeclareInputText{168}{\cyre}
\DeclareInputText{169}{\cyryo}
\DeclareInputText{170}{\cyrzh}
\DeclareInputText{173}{\cyrz}
\DeclareInputText{224}{\cyri}
\DeclareInputText{225}{\cyrishrt}
\DeclareInputText{226}{\cyrk}
\DeclareInputText{227}{\cyrl}
\DeclareInputText{228}{\cyrm}
\DeclareInputText{229}{\cyrn}
\DeclareInputText{230}{\cyro}
\DeclareInputText{231}{\cyrotld}
\DeclareInputText{232}{\cyrp}
\DeclareInputText{233}{\cyrr}
\DeclareInputText{234}{\cyrs}
\DeclareInputText{235}{\cyrt}
\DeclareInputText{236}{\cyru}
\DeclareInputText{237}{\cyry}
\DeclareInputText{238}{\cyrf}
\DeclareInputText{239}{\cyrh}
\DeclareInputText{240}{\cyrc}
\DeclareInputText{241}{\cyrch}
\DeclareInputText{242}{\cyrsh}
\DeclareInputText{243}{\cyrshch}
\DeclareInputText{244}{\cyrhrdsn}
\DeclareInputText{245}{\cyrery}
\DeclareInputText{248}{\cyrsftsn}
\DeclareInputText{252}{\cyrerev}
\DeclareInputText{253}{\cyryu}
\DeclareInputText{254}{\cyrya}
%
\endinput
%% 
%% End of file `cpmnk.def'.
