% Copyright 2006 Konstantin Korikov <lostclus@ua.fm>
%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2003/12/01 or later.
%
% This work has the LPPL maintenance status "maintained".
% 
% This Current Maintainer of this work is Konstantin Korikov.
%
% This work consists of all files listed in manifest.txt.
%

%
% This is automaticaly generated file, do not edit it.
%

\ProvidesFile{eskdrussian.def}[2010/01/17 v0.98 Language File]

\newcommand{\ESKDcolumnIVname}{%
  \cyr\CYRL\cyri\cyrt.}
\newcommand{\ESKDcolumnVname}{%
  \cyr\CYRM\cyra\cyrs\cyrs\cyra}
\newcommand{\ESKDcolumnVIname}{%
  \cyr\CYRM\cyra\cyrs\cyrsh\cyrt\cyra\cyrb}
\newcommand{\ESKDcolumnVIIname}{%
  \cyr\CYRL\cyri\cyrs\cyrt}
\newcommand{\ESKDcolumnVIItwosideName}{%
  \cyr\CYRS\cyrt\cyrr.}
\newcommand{\ESKDcolumnVIIIname}{%
  \cyr\CYRL\cyri\cyrs\cyrt\cyro\cyrv}
\newcommand{\ESKDcolumnVIIItwosideName}{%
  \cyr\CYRS\cyrt\cyrr\cyra\cyrn\cyri\cyrc}
\newcommand{\ESKDcolumnXfIname}{%
  \cyr\CYRR\cyra\cyrz\cyrr\cyra\cyrb.}
\newcommand{\ESKDcolumnXfIIname}{%
  \cyr\CYRP\cyrr\cyro\cyrv.}
\newcommand{\ESKDcolumnXfIIIname}{%
  \cyr\CYRT. \cyrk\cyro\cyrn\cyrt\cyrr.}
\newcommand{\ESKDcolumnXfIVname}{}
\newcommand{\ESKDcolumnXfVname}{%
  \cyr\CYRN. \cyrk\cyro\cyrn\cyrt\cyrr.}
\newcommand{\ESKDcolumnXfVIname}{%
  \cyr\CYRU\cyrt\cyrv.}
\newcommand{\ESKDcolumnXIVname}{%
  \cyr\CYRI\cyrz\cyrm.}
\newcommand{\ESKDcolumnXVname}{%
  \cyr\CYRL\cyri\cyrs\cyrt}
\newcommand{\ESKDcolumnXVIname}{%
  \No\ \cyr\cyrd\cyro\cyrk\cyru\cyrm.}
\newcommand{\ESKDcolumnXVIIname}{%
  \cyr\CYRP\cyro\cyrd\cyrp.}
\newcommand{\ESKDcolumnXVIIIname}{%
  \cyr\CYRD\cyra\cyrt\cyra}
\newcommand{\ESKDcolumnXIXname}{%
  \cyr\CYRI\cyrn\cyrv. \No\ \cyrp\cyro\cyrd\cyrl.}
\newcommand{\ESKDcolumnXXname}{%
  \cyr\CYRP\cyro\cyrd\cyrp. \cyri\ \cyrd\cyra\cyrt\cyra}
\newcommand{\ESKDcolumnXXIname}{%
  \cyr\CYRV\cyrz\cyra\cyrm. \cyri\cyrn\cyrv. \No}
\newcommand{\ESKDcolumnXXIIname}{%
  \cyr\CYRI\cyrn\cyrv. \No\ \cyrd\cyru\cyrb\cyrl.}
\newcommand{\ESKDcolumnXXIIIname}{%
  \cyr\CYRP\cyro\cyrd\cyrp. \cyri\ \cyrd\cyra\cyrt\cyra}
\newcommand{\ESKDcolumnXXIVname}{%
  \cyr\CYRS\cyrp\cyrr\cyra\cyrv. \No}
\newcommand{\ESKDcolumnXXVname}{%
  \cyr\CYRP\cyre\cyrr\cyrv. \cyrp\cyrr\cyri\cyrm\cyre\cyrn.}
\newcommand{\ESKDcolumnXXXIname}{%
  \cyr\CYRK\cyro\cyrp\cyri\cyrr\cyro\cyrv\cyra\cyrl}
\@namedef{ESKDa0FormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \CYRA{}0}
\@namedef{ESKDa1FormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \CYRA{}1}
\@namedef{ESKDa2FormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \CYRA{}2}
\@namedef{ESKDa3FormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \CYRA{}3}
\@namedef{ESKDa4FormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \CYRA{}4}
\@namedef{ESKDemptyFormatName}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt\ \ \ \ }
\newcommand{\ESKDcolumnXXXIIIname}{%
  \cyr\CYRZ\cyro\cyrn\cyra}

\newcommand{\ESKDagreedName}{%
  \cyr\CYRS\cyro\cyrg\cyrl\cyra\cyrs\cyro\cyrv\cyra\cyrn\cyro}
\newcommand{\ESKDapprovingName}{%
  \cyr\CYRU\cyrt\cyrv\cyre\cyrr\cyrzh\cyrd\cyra\cyryu}
\newcommand{\ESKDapprovedName}{%
  \cyr\CYRU\cyrt\cyrv\cyre\cyrr\cyrzh\cyrd\cyre\cyrn}
\newcommand{\ESKDapprovingSheetName}{%
  \cyr\CYRL\cyri\cyrs\cyrt\ %
  \cyru\cyrt\cyrv\cyre\cyrr\cyrzh\cyrd\cyre\cyrn\cyri\cyrya}

\newlength{\ESKDexplanWidth}
\setlength{\ESKDexplanWidth}{1.8em}

\addto\captionsrussian{%
  \def\tablename{{\cyr\CYRT\cyra\cyrb\cyrl\cyri\cyrc\cyra}}%
  \def\figurename{{\cyr\CYRR\cyri\cyrs\cyru\cyrn\cyro\cyrk}}%
}

\newcommand{\ESKDspecColumnIname}{%
  \cyr\CYRF\cyro\cyrr\cyrm\cyra\cyrt}
\newcommand{\ESKDspecColumnIIname}{%
  \cyr\CYRZ\cyro\cyrn\cyra}
\newcommand{\ESKDspecColumnIIIname}{%
  \cyr\CYRP\cyro\cyrz.}
\newcommand{\ESKDspecColumnIVname}{%
  \cyr\CYRO\cyrb\cyro\cyrz\cyrn\cyra\cyrch\cyre\cyrn\cyri\cyre}
\newcommand{\ESKDspecColumnVname}{%
  \cyr\CYRN\cyra\cyri\cyrm\cyre\cyrn\cyro\cyrv\cyra\cyrn\cyri\cyre}
\newcommand{\ESKDspecColumnVIname}{%
  \cyr\CYRK\cyro\cyrl.}
\newcommand{\ESKDspecColumnVIIname}{%
  \cyr\CYRP\cyrr\cyri\cyrm\cyre\cyrch\cyra\cyrn\cyri\cyre}

\newcommand{\ESKDspecIIcolumnIname}{\ESKDspecColumnIname}
\newcommand{\ESKDspecIIcolumnIIname}{\ESKDspecColumnIIname}
\newcommand{\ESKDspecIIcolumnIIIname}{\ESKDspecColumnIIIname}
\newcommand{\ESKDspecIIcolumnIVname}{\ESKDspecColumnIVname}
\newcommand{\ESKDspecIIcolumnVname}{\ESKDspecColumnVname}
\newcommand{\ESKDspecIIcolumnVIname}{\ESKDspecColumnVIname}
\newcommand{\ESKDspecIIcolumnVIIname}{%
  \cyr\CYRM\cyra\cyrs\cyrs\cyra}
\newcommand{\ESKDspecIIcolumnVIIIname}{%
  \cyr\CYRM\cyra\cyrt\cyre\cyrr\cyri\cyra\cyrl}
\newcommand{\ESKDspecIIcolumnIXname}{\ESKDspecColumnVIIname}

\newcommand{\ESKDchangeSheetName}{%
  \cyr\CYRL\cyri\cyrs\cyrt\ %
  \cyrr\cyre\cyrg\cyri\cyrs\cyrt\cyrr\cyra\cyrc\cyri\cyri\ %
  \cyri\cyrz\cyrm\cyre\cyrn\cyre\cyrn\cyri\cyrishrt}
\newcommand{\ESKDchngColumnsIIhName}{%
  \cyr\CYRN\cyro\cyrm\cyre\cyrr\cyra\ \cyrl\cyri\cyrs\cyrt\cyro\cyrv\ %
  (\cyrs\cyrt\cyrr\cyra\cyrn\cyri\cyrc)}
\newcommand{\ESKDchngColumnIIname}{%
  \cyr\cyri\cyrz\-\cyrm\cyre\-\cyrn\cyre\cyrn\-\cyrn\cyrery\cyrh}
\newcommand{\ESKDchngColumnIIIname}{%
  \cyr\cyrz\cyra\-\cyrm\cyre\-\cyrn\cyre\cyrn\-\cyrn\cyrery\cyrh}
\newcommand{\ESKDchngColumnIVname}{%
  \cyr\cyrn\cyro\-\cyrv\cyrery\cyrh}
\newcommand{\ESKDchngColumnVname}{%
  \cyr\cyra\cyrn\-\cyrn\cyru\-\cyrl\cyri\-\cyrr\cyro\-\cyrv\cyra\cyrn\-%
  \cyrn\cyrery\cyrh}
\newcommand{\ESKDchngColumnVIname}{%
  \cyr\CYRV\cyrs\cyre\cyrg\cyro\ \cyrl\cyri\cyrs\cyrt\cyro\cyrv\ %
  (\cyrs\cyrt\cyrr\cyra\cyrn\cyri\cyrc) \cyrv\ \cyrd\cyro\cyrk\cyru\cyrm.}
\newcommand{\ESKDchngColumnVIIIname}{%
  \cyr\CYRV\cyrh\cyro\cyrd\cyrya\cyrshch\cyri\cyrishrt\ \No\ %
  \cyrs\cyro\cyrp\cyrr\cyro\cyrv\cyro\cyrd\cyri\cyrt\cyre\cyrl\cyrsftsn
  \cyrn\cyro\cyrg\cyro\ \cyrd\cyro\cyrk\cyru\cyrm. \cyri\ %
  \cyrd\cyra\cyrt\cyra}

\def\@Asbuk#1{\ifcase#1\or
  \CYRA\or\CYRB\or\CYRV\or\CYRG\or\CYRD\or\CYRE\or\CYRZH\or
  \CYRI\or\CYRK\or\CYRL\or\CYRM\or\CYRN\or
  \CYRP\or\CYRR\or\CYRS\or\CYRT\or\CYRU\or\CYRF\or\CYRH\or
  \CYRC\or\CYRSH\or\CYRSHCH\or\CYREREV\or\CYRYU\or
  \CYRYA\else{\@tempcnta \number #1\relax
      \advance\@tempcnta -25\relax
      \protect\number\@tempcnta}
  \fi}
\def\@asbuk#1{\ifcase#1\or
  \cyra\or\cyrb\or\cyrv\or\cyrg\or\cyrd\or\cyre\or\cyrzh\or
  \cyri\or\cyrk\or\cyrl\or\cyrm\or\cyrn\or
  \cyrp\or\cyrr\or\cyrs\or\cyrt\or\cyru\or\cyrf\or\cyrh\or
  \cyrc\or\cyrsh\or\cyrshch\or\cyrerev\or\cyryu\or
  \cyrya\else{\@tempcnta \number #1\relax
      \advance\@tempcnta -25\relax
      \protect\number\@tempcnta}
  \fi}

