%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: lmsenc.def
%      Author: Oliver Corff
%        Date: March 1st, 1999
%     Version: 0.3
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: Local Mongolian Bicig Encoding Definition
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
%
\ProvidesFile{lmsenc.def}
	[1998/06/01 v0.2 Mongolian Language Support Bicig Encoding]
%
%
\DeclareFontEncoding{LMS}{}{}{}
\DeclareFontSubstitution{LMS}{bcgh}{m}{n}
%
\DeclareTextComposite{\"}{LMS}{a}{69}
\DeclareTextComposite{\"}{LMS}{o}{79}
\DeclareTextComposite{\"}{LMS}{u}{85}
%
\DeclareTextSymbol{\titem}{LMS}{"40}
\DeclareTextSymbol{\shud}{LMS}{"61}
\DeclareTextSymbol{\secondaryshud}{LMS}{"41}
\DeclareTextSymbol{\shilbe}{LMS}{"69}
\DeclareTextSymbol{\gedes}{LMS}{"6F}
\DeclareTextSymbol{\secondarygedes}{LMS}{"4F}
\DeclareTextSymbol{\cegteishud}{LMS}{"6E}
\DeclareTextSymbol{\lewer}{LMS}{"6C}
\DeclareTextSymbol{\suuliinlewer}{LMS}{"4C}
\DeclareTextSymbol{\tertiarylewer}{LMS}{"51}
\DeclareTextSymbol{\mewer}{LMS}{"6D}
\DeclareTextSymbol{\suuliinmewer}{LMS}{"4D}
\DeclareTextSymbol{\xewteeqix}{LMS}{"78}
\DeclareTextSymbol{\dawxarcegtxewteeqix}{LMS}{"58}
\DeclareTextSymbol{\halfnum}{LMS}{"67}
\DeclareTextSymbol{\num}{LMS}{"49}
\DeclareTextSymbol{\halfnumtgedes}{LMS}{"42}
\DeclareTextSymbol{\numtaigedes}{LMS}{"62}
\DeclareTextSymbol{\buruuxarsangedes}{LMS}{"74}
\DeclareTextSymbol{\gedesteishilbe}{LMS}{"64}
\DeclareTextSymbol{\erweeljinshilbe}{LMS}{"72}
\DeclareTextSymbol{\secerweeljin}{LMS}{"52}
\DeclareTextSymbol{\bosooshilbe}{LMS}{"7A}
\DeclareTextSymbol{\etgershilbe}{LMS}{"79}
\DeclareTextSymbol{\zawj}{LMS}{"73}
\DeclareTextSymbol{\suuliinzawj}{LMS}{"53}
\DeclareTextSymbol{\dawxarcegtzawj}{LMS}{"71}
\DeclareTextSymbol{\sereeewer}{LMS}{"63}
\DeclareTextSymbol{\matgarshilbe}{LMS}{"76}
\DeclareTextSymbol{\bituushilbe}{LMS}{"68}
\DeclareTextSymbol{\secondaryqagt}{LMS}{"4B}
\DeclareTextSymbol{\qagt}{LMS}{"6B}
\DeclareTextSymbol{\secnumtdelbenqix}{LMS}{"50}
\DeclareTextSymbol{\numtdelbenqix}{LMS}{"70}
\DeclareTextSymbol{\secsertenqixtnum}{LMS}{"46}
\DeclareTextSymbol{\sertenqixtnum}{LMS}{"66}
\DeclareTextSymbol{\zadgaizardigt}{LMS}{"5A}
\DeclareTextSymbol{\bituuzardigt}{LMS}{"43}
\DeclareTextSymbol{\malgaitaititem}{LMS}{"6A}
\DeclareTextSymbol{\suul}{LMS}{"65}
\DeclareTextSymbol{\orxic}{LMS}{"45}
\DeclareTextSymbol{\biodoisuul}{LMS}{"59}
\DeclareTextSymbol{\bagodoisuul}{LMS}{"47}
\DeclareTextSymbol{\nceg}{LMS}{"2D}
\DeclareTextSymbol{\gceg}{LMS}{"3D}
\DeclareTextSymbol{\ceg}{LMS}{"2C}
\DeclareTextSymbol{\dorwoljin}{LMS}{"3B}

\DeclareTextSymbolDefault{\shud}{LMS}
\DeclareTextSymbolDefault{\secondaryshud}{LMS}
\DeclareTextSymbolDefault{\gedes}{LMS}
\DeclareTextSymbolDefault{\secondarygedes}{LMS}
\DeclareTextSymbolDefault{\shilbe}{LMS}
\DeclareTextSymbolDefault{\cegteishud}{LMS}
\DeclareTextSymbolDefault{\lewer}{LMS}
\DeclareTextSymbolDefault{\suuliinlewer}{LMS}
\DeclareTextSymbolDefault{\tertiarylewer}{LMS}
\DeclareTextSymbolDefault{\mewer}{LMS}
\DeclareTextSymbolDefault{\suuliinmewer}{LMS}
\DeclareTextSymbolDefault{\xewteeqix}{LMS}
\DeclareTextSymbolDefault{\dawxarcegtxewtee}{LMS}
\DeclareTextSymbolDefault{\halfnum}{LMS}
\DeclareTextSymbolDefault{\num}{LMS}
\DeclareTextSymbolDefault{\halfnumtgedes}{LMS}
\DeclareTextSymbolDefault{\numtoigedes}{LMS}
\DeclareTextSymbolDefault{\buruuxarsangedes}{LMS}
\DeclareTextSymbolDefault{\gedesteishilbe}{LMS}
\DeclareTextSymbolDefault{\erweeljinshilbe}{LMS}
\DeclareTextSymbolDefault{\secerweeljin}{LMS}
\DeclareTextSymbolDefault{\bosooshilbe}{LMS}
\DeclareTextSymbolDefault{\etgershilbe}{LMS}
\DeclareTextSymbolDefault{\zawj}{LMS}
\DeclareTextSymbolDefault{\suuliinzawj}{LMS}
\DeclareTextSymbolDefault{\dawxarcegtzawj}{LMS}
\DeclareTextSymbolDefault{\sereeewer}{LMS}
\DeclareTextSymbolDefault{\matgarshilbe}{LMS}
\DeclareTextSymbolDefault{\bituushilbe}{LMS}
\DeclareTextSymbolDefault{\secondaryqagt}{LMS}
\DeclareTextSymbolDefault{\qagt}{LMS}
\DeclareTextSymbolDefault{\secnumtdelbenq}{LMS}
\DeclareTextSymbolDefault{\numtdelbenqix}{LMS}
\DeclareTextSymbolDefault{\secsertenqixt}{LMS}
\DeclareTextSymbolDefault{\sertenqixtnum}{LMS}
\DeclareTextSymbolDefault{\zadgaizardigt}{LMS}
\DeclareTextSymbolDefault{\bituuzardigt}{LMS}
\DeclareTextSymbolDefault{\malgaitaititem}{LMS}
\DeclareTextSymbolDefault{\suul}{LMS}
\DeclareTextSymbolDefault{\orxic}{LMS}
\DeclareTextSymbolDefault{\biodoisuul}{LMS}
\DeclareTextSymbolDefault{\bagodoisuul}{LMS}
\DeclareTextSymbolDefault{\nceg}{LMS}
\DeclareTextSymbolDefault{\gceg}{LMS}
\DeclareTextSymbolDefault{\ceg}{LMS}
\DeclareTextSymbolDefault{\dorwoljin}{LMS}
%
\endinput
