%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: cpmos.def
%      Author: Oliver Corff
%        Date: February 8th, 1998
%     Version: 0.3
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: MOS codepage definition
%
%        Note: This file forms part of the MonTeX package which
%              should always be distributed in complete form.
%
%              The code positions in this file were cross-checked
%              by Vladimir Volovich and are compatible in position
%              and name with those of the emerging T2 standard.
%
%              Thank you very much, Vladimir!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
\ProvidesFile{cpmos.def}
   [1997/11/01 v0.1 Input encoding file for MOS encoding]
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
%
% Cyrillic Letters
%
\DeclareInputText{128}{\CYRA}
\DeclareInputText{129}{\CYRB}
\DeclareInputText{130}{\CYRV}
\DeclareInputText{131}{\CYRG}
\DeclareInputText{132}{\CYRD}
\DeclareInputText{133}{\CYRE}
\DeclareInputText{160}{\CYRYO}
\DeclareInputText{134}{\CYRZH}
\DeclareInputText{135}{\CYRZ}
\DeclareInputText{136}{\CYRI}
\DeclareInputText{137}{\CYRISHRT}
\DeclareInputText{138}{\CYRK}
\DeclareInputText{139}{\CYRL}
\DeclareInputText{140}{\CYRM}
\DeclareInputText{141}{\CYRN}
\DeclareInputText{142}{\CYRO}
\DeclareInputText{153}{\CYROTLD}
\DeclareInputText{143}{\CYRP}
\DeclareInputText{144}{\CYRR}
\DeclareInputText{145}{\CYRS}
\DeclareInputText{146}{\CYRT}
\DeclareInputText{147}{\CYRU}
\DeclareInputText{154}{\CYRY}
\DeclareInputText{148}{\CYRF}
\DeclareInputText{149}{\CYRH}
\DeclareInputText{150}{\CYRC}
\DeclareInputText{151}{\CYRCH}
\DeclareInputText{152}{\CYRSH}
\DeclareInputText{164}{\CYRSHCH}
\DeclareInputText{162}{\CYRHRDSN}
\DeclareInputText{155}{\CYRERY}
\DeclareInputText{156}{\CYRSFTSN}
\DeclareInputText{157}{\CYREREV}
\DeclareInputText{158}{\CYRYU}
\DeclareInputText{159}{\CYRYA}
\DeclareInputText{224}{\cyra}
\DeclareInputText{225}{\cyrb}
\DeclareInputText{226}{\cyrv}
\DeclareInputText{227}{\cyrg}
\DeclareInputText{228}{\cyrd}
\DeclareInputText{229}{\cyre}
\DeclareInputText{161}{\cyryo}
\DeclareInputText{230}{\cyrzh}
\DeclareInputText{231}{\cyrz}
\DeclareInputText{232}{\cyri}
\DeclareInputText{233}{\cyrishrt}
\DeclareInputText{234}{\cyrk}
\DeclareInputText{235}{\cyrl}
\DeclareInputText{236}{\cyrm}
\DeclareInputText{237}{\cyrn}
\DeclareInputText{238}{\cyro}
\DeclareInputText{249}{\cyrotld}
\DeclareInputText{239}{\cyrp}
\DeclareInputText{240}{\cyrr}
\DeclareInputText{241}{\cyrs}
\DeclareInputText{242}{\cyrt}
\DeclareInputText{243}{\cyru}
\DeclareInputText{250}{\cyry}
\DeclareInputText{244}{\cyrf}
\DeclareInputText{245}{\cyrh}
\DeclareInputText{246}{\cyrc}
\DeclareInputText{247}{\cyrch}
\DeclareInputText{248}{\cyrsh}
\DeclareInputText{165}{\cyrshch}
\DeclareInputText{163}{\cyrhrdsn}
\DeclareInputText{251}{\cyrery}
\DeclareInputText{252}{\cyrsftsn}
\DeclareInputText{253}{\cyrerev}
\DeclareInputText{254}{\cyryu}
\DeclareInputText{168}{\cyrya}
%
\endinput
%% 
%% End of file `cpmos.def'.
