%% mn.def v1.0 2007/03/19
%% Copyright 2007 by D. Batmunkh, National University of Mongolia
%% email batmunkh@num.edu.mn
%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2005/12/01 or later.

\ProvidesFile{mn.def}
  [2007/03/19 v1.0 Input encoding file]
\makeatletter
\DeclareInputText{192}{\CYRA}
\DeclareInputText{193}{\CYRB}
\DeclareInputText{194}{\CYRV}
\DeclareInputText{195}{\CYRG}
\DeclareInputText{196}{\CYRD}
\DeclareInputText{197}{\CYRE}
\DeclareInputText{156}{\CYRYO}
\DeclareInputText{168}{\CYRYO}
\DeclareInputText{198}{\CYRZH}
\DeclareInputText{199}{\CYRZ}
\DeclareInputText{200}{\CYRI}
\DeclareInputText{201}{\CYRISHRT}
\DeclareInputText{202}{\CYRK}
\DeclareInputText{203}{\CYRL}
\DeclareInputText{204}{\CYRM}
\DeclareInputText{205}{\CYRN}
\DeclareInputText{206}{\CYRO}
\DeclareInputText{144}{\CYROTLD}
\DeclareInputText{170}{\CYROTLD}
\DeclareInputText{207}{\CYRP}
\DeclareInputText{208}{\CYRR}
\DeclareInputText{209}{\CYRS}
\DeclareInputText{210}{\CYRT}
\DeclareInputText{211}{\CYRU}
\DeclareInputText{147}{\CYRY}
\DeclareInputText{175}{\CYRY}
\DeclareInputText{212}{\CYRF}
\DeclareInputText{213}{\CYRH}
\DeclareInputText{214}{\CYRC}
\DeclareInputText{215}{\CYRCH}
\DeclareInputText{216}{\CYRSH}
\DeclareInputText{217}{\CYRSHCH}
\DeclareInputText{218}{\CYRHRDSN}
\DeclareInputText{219}{\CYRERY}
\DeclareInputText{220}{\CYRSFTSN}
\DeclareInputText{221}{\CYREREV}
\DeclareInputText{222}{\CYRYU}
\DeclareInputText{223}{\CYRYA}
\DeclareInputText{224}{\cyra}
\DeclareInputText{225}{\cyrb}
\DeclareInputText{226}{\cyrv}
\DeclareInputText{227}{\cyrg}
\DeclareInputText{228}{\cyrd}
\DeclareInputText{229}{\cyre}
\DeclareInputText{188}{\cyryo}
\DeclareInputText{184}{\cyryo}
\DeclareInputText{230}{\cyrzh}
\DeclareInputText{231}{\cyrz}
\DeclareInputText{232}{\cyri}
\DeclareInputText{233}{\cyrishrt}
\DeclareInputText{234}{\cyrk}
\DeclareInputText{235}{\cyrl}
\DeclareInputText{236}{\cyrm}
\DeclareInputText{237}{\cyrn}
\DeclareInputText{238}{\cyro}
\DeclareInputText{176}{\cyrotld}
\DeclareInputText{186}{\cyrotld}
\DeclareInputText{239}{\cyrp}
\DeclareInputText{240}{\cyrr}
\DeclareInputText{241}{\cyrs}
\DeclareInputText{242}{\cyrt}
\DeclareInputText{243}{\cyru}
\DeclareInputText{179}{\cyry}
\DeclareInputText{191}{\cyry}
\DeclareInputText{244}{\cyrf}
\DeclareInputText{245}{\cyrh}
\DeclareInputText{246}{\cyrc}
\DeclareInputText{247}{\cyrch}
\DeclareInputText{248}{\cyrsh}
\DeclareInputText{249}{\cyrshch}
\DeclareInputText{250}{\cyrhrdsn}
\DeclareInputText{251}{\cyrery}
\DeclareInputText{252}{\cyrsftsn}
\DeclareInputText{253}{\cyrerev}
\DeclareInputText{254}{\cyryu}
\DeclareInputText{255}{\cyrya}
\DeclareInputText{130}{\quotesinglbase}
\DeclareInputText{132}{\quotedblbase}
\DeclareInputText{133}{\dots}
\DeclareInputText{134}{\dag}
\DeclareInputText{135}{\ddag}
\DeclareInputText{137}{\textperthousand}
\DeclareInputText{139}{\guilsinglleft}
\DeclareInputText{145}{\textquoteleft}
\DeclareInputText{146}{\textquoteright}
\DeclareInputText{149}{\textbullet}
\DeclareInputText{150}{\textendash}
\DeclareInputText{151}{\textemdash}
\DeclareInputText{153}{\texttrademark}
\DeclareInputText{155}{\guilsinglright}
\DeclareInputText{160}{\nobreakspace}
\DeclareInputText{164}{\textcurrency}
\DeclareInputText{167}{\S}
\DeclareInputText{169}{\copyright}
\DeclareInputText{171}{\guillemotleft}
\DeclareInputMath{172}{\lnot}
\DeclareInputText{173}{\-}
\DeclareInputText{174}{\textregistered}
\DeclareInputMath{177}{\pm}
\DeclareInputMath{181}{\mu}
\DeclareInputText{182}{\P}
\DeclareInputText{183}{\textperiodcentered}
\DeclareInputText{185}{\textnumero}
\DeclareInputText{187}{\guillemotright}
\makeatother
\endinput
