%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: lmcenc.def
%      Author: Oliver Corff
%        Date: February 8th, 1999
%     Version: 0.3
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: Local Mongolian Cyrillic Encoding Definition,
%              Now LH-conformant. Thank you, Vladimir Volovich,
%              for inspecting and correcting individual code
%              positions!
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
%
\ProvidesFile{lmcenc.def}
	[1998/06/01 v0.2 Mongolian Language Support Encoding]
\DeclareFontEncoding{LMC}{}{}{}
\DeclareFontSubstitution{LMC}{cmr}{m}{n}
%\DeclareErrorFont{LMC}{cmr}{m}{n}{10}
%
% Umlaute etc.
%
\DeclareTextAccent{\"}{LMC}{"7F}
\DeclareTextSymbol{\leftguillemot}{LMC}{019}
\DeclareTextSymbol{\rightguillemot}{LMC}{020}
\let\lgu\leftguillemot
\let\rgu\rightguillemot
%
% Currency, no., etc.
%
\DeclareTextSymbol{\No}{LMC}{249}
	\DeclareTextSymbolDefault{\No}{LMC}
\DeclareTextSymbol{\MyTogrog}{LMC}{250}
	\DeclareTextSymbolDefault{\MyTogrog}{LMC}
\DeclareTextSymbol{\mytogrog}{LMC}{251}
	\DeclareTextSymbolDefault{\mytogrog}{LMC}
%
% Cyrillic Letters
%
\DeclareTextSymbol{\CYRA}{LMC}{65}
\DeclareTextSymbol{\CYRB}{LMC}{66}
\DeclareTextSymbol{\CYRV}{LMC}{87}
\DeclareTextSymbol{\CYRG}{LMC}{71}
\DeclareTextSymbol{\CYRD}{LMC}{68}
\DeclareTextSymbol{\CYRE}{LMC}{69}
\DeclareTextSymbol{\CYRYO}{LMC}{203}
	\DeclareTextSymbol{\Yo}{LMC}{203}
	\DeclareTextComposite{\"}{LMC}{E}{203}
\DeclareTextSymbol{\CYRZH}{LMC}{74}
\DeclareTextSymbol{\CYRZ}{LMC}{90}
\DeclareTextSymbol{\CYRI}{LMC}{73}
\DeclareTextSymbol{\CYRISHRT}{LMC}{207}
	\DeclareTextComposite{\"}{LMC}{I}{207}
\DeclareTextSymbol{\CYRK}{LMC}{75}
\DeclareTextSymbol{\CYRL}{LMC}{76}
\DeclareTextSymbol{\CYRM}{LMC}{77}
\DeclareTextSymbol{\CYRN}{LMC}{78}
\DeclareTextSymbol{\CYRO}{LMC}{79}
\DeclareTextSymbol{\CYROTLD}{LMC}{214}
	\DeclareTextComposite{\"}{LMC}{O}{214}
\DeclareTextSymbol{\CYRP}{LMC}{80}
\DeclareTextSymbol{\CYRR}{LMC}{82}
\DeclareTextSymbol{\CYRS}{LMC}{83}
\DeclareTextSymbol{\CYRT}{LMC}{84}
\DeclareTextSymbol{\CYRU}{LMC}{85}
\DeclareTextSymbol{\CYRY}{LMC}{220}
	\DeclareTextComposite{\"}{LMC}{U}{220}
\DeclareTextSymbol{\CYRF}{LMC}{70}
\DeclareTextSymbol{\CYRH}{LMC}{88}
\DeclareTextSymbol{\CYRHSHA}{LMC}{72}
\DeclareTextSymbol{\CYRC}{LMC}{67}
\DeclareTextSymbol{\CYRCH}{LMC}{81}
	\DeclareTextSymbol{\Ch}{LMC}{81 }
\DeclareTextSymbol{\CYRSH}{LMC}{"092 }
	\DeclareTextSymbol{\Sh}{LMC}{"092 }
\DeclareTextSymbol{\CYRSHCH}{LMC}{"090 }
	\DeclareTextSymbol{\Qh}{LMC}{"090 }
	\DeclareTextSymbol{\Sc}{LMC}{"090 }
\DeclareTextSymbol{\CYRHRDSN}{LMC}{"093 }
	\DeclareTextSymbol{\Y}{LMC}{"093 }
\DeclareTextSymbol{\CYRERY}{LMC}{89}
\DeclareTextSymbol{\CYRSFTSN}{LMC}{"094 }
	\DeclareTextSymbol{\I}{LMC}{"094 }
\DeclareTextSymbol{\CYREREV}{LMC}{196}
	\DeclareTextComposite{\"}{LMC}{A}{196}
\DeclareTextSymbol{\CYRYU}{LMC}{"095 }
	\DeclareTextSymbol{\Yu}{LMC}{"095 }
\DeclareTextSymbol{\CYRYA}{LMC}{"096 }
	\DeclareTextSymbol{\Ya}{LMC}{"096 }
%
\DeclareTextSymbol{\cyra}{LMC}{97}
\DeclareTextSymbol{\cyrb}{LMC}{98}
\DeclareTextSymbol{\cyrv}{LMC}{119}
\DeclareTextSymbol{\cyrg}{LMC}{103}
\DeclareTextSymbol{\cyrd}{LMC}{100}
\DeclareTextSymbol{\cyre}{LMC}{101}
\DeclareTextSymbol{\cyryo}{LMC}{235}
	\DeclareTextSymbol{\yo}{LMC}{235}
	\DeclareTextComposite{\"}{LMC}{e}{235}
\DeclareTextSymbol{\cyrzh}{LMC}{106}
\DeclareTextSymbol{\cyrz}{LMC}{122}
\DeclareTextSymbol{\cyri}{LMC}{105}
\DeclareTextSymbol{\cyrishrt}{LMC}{239}
	\DeclareTextComposite{\"}{LMC}{i}{239}
	\DeclareTextComposite{\"}{LMC}{\i}{239}
\DeclareTextSymbol{\cyrk}{LMC}{107}
\DeclareTextSymbol{\cyrl}{LMC}{108}
\DeclareTextSymbol{\cyrm}{LMC}{109}
\DeclareTextSymbol{\cyrn}{LMC}{110}
\DeclareTextSymbol{\cyro}{LMC}{111}
\DeclareTextSymbol{\cyrotld}{LMC}{246}
	\DeclareTextComposite{\"}{LMC}{o}{246}
\DeclareTextSymbol{\cyrp}{LMC}{112}
\DeclareTextSymbol{\cyrr}{LMC}{114}
\DeclareTextSymbol{\cyrs}{LMC}{115}
\DeclareTextSymbol{\cyrt}{LMC}{116}
\DeclareTextSymbol{\cyru}{LMC}{117}
\DeclareTextSymbol{\cyry}{LMC}{252}
	\DeclareTextComposite{\"}{LMC}{u}{252}
\DeclareTextSymbol{\cyrf}{LMC}{102}
\DeclareTextSymbol{\cyrh}{LMC}{120}
\DeclareTextSymbol{\cyrhsha}{LMC}{104}
\DeclareTextSymbol{\cyrc}{LMC}{99}
\DeclareTextSymbol{\cyrch}{LMC}{113}
	\DeclareTextSymbol{\ch}{LMC}{113}
\DeclareTextSymbol{\cyrsh}{LMC}{"0B2 }
	\DeclareTextSymbol{\sh}{LMC}{"0B2 }
\DeclareTextSymbol{\cyrshch}{LMC}{"0B0 }
	\DeclareTextSymbol{\qh}{LMC}{"0B0 }
	\DeclareTextSymbol{\sc}{LMC}{"0B0 }
\DeclareTextSymbol{\cyrhrdsn}{LMC}{"0B3 }
	\DeclareTextSymbol{\y}{LMC}{"0B3 }
\DeclareTextSymbol{\cyrery}{LMC}{121}
\DeclareTextSymbol{\cyrsftsn}{LMC}{"0B4 }
	\DeclareTextSymbol{\i}{LMC}{"0B4 }
\DeclareTextSymbol{\cyrerev}{LMC}{228}
	\DeclareTextComposite{\"}{LMC}{a}{228}
\DeclareTextSymbol{\cyryu}{LMC}{"0B5 }
	\DeclareTextSymbol{\yu}{LMC}{"0B5 }
\DeclareTextSymbol{\cyrya}{LMC}{"0B6 }
	\DeclareTextSymbol{\ya}{LMC}{"0B6 }
%
\DeclareTextSymbolDefault{\CYRA}{LMC}
\DeclareTextSymbolDefault{\CYRB}{LMC}
\DeclareTextSymbolDefault{\CYRV}{LMC}
\DeclareTextSymbolDefault{\CYRG}{LMC}
\DeclareTextSymbolDefault{\CYRD}{LMC}
\DeclareTextSymbolDefault{\CYRE}{LMC}
\DeclareTextSymbolDefault{\CYRYO}{LMC}
\DeclareTextSymbolDefault{\CYRZH}{LMC}
\DeclareTextSymbolDefault{\CYRZ}{LMC}
\DeclareTextSymbolDefault{\CYRI}{LMC}
\DeclareTextSymbolDefault{\CYRISHRT}{LMC}
\DeclareTextSymbolDefault{\CYRK}{LMC}
\DeclareTextSymbolDefault{\CYRL}{LMC}
\DeclareTextSymbolDefault{\CYRM}{LMC}
\DeclareTextSymbolDefault{\CYRN}{LMC}
\DeclareTextSymbolDefault{\CYRO}{LMC}
\DeclareTextSymbolDefault{\CYROTLD}{LMC}
\DeclareTextSymbolDefault{\CYRP}{LMC}
\DeclareTextSymbolDefault{\CYRR}{LMC}
\DeclareTextSymbolDefault{\CYRS}{LMC}
\DeclareTextSymbolDefault{\CYRT}{LMC}
\DeclareTextSymbolDefault{\CYRU}{LMC}
\DeclareTextSymbolDefault{\CYRY}{LMC}
\DeclareTextSymbolDefault{\CYRF}{LMC}
\DeclareTextSymbolDefault{\CYRH}{LMC}
\DeclareTextSymbolDefault{\CYRHSHA}{LMC}
\DeclareTextSymbolDefault{\CYRC}{LMC}
\DeclareTextSymbolDefault{\CYRCH}{LMC}
\DeclareTextSymbolDefault{\CYRSH}{LMC}
\DeclareTextSymbolDefault{\CYRSHCH}{LMC}
\DeclareTextSymbolDefault{\CYRHRDSN}{LMC}
\DeclareTextSymbolDefault{\CYRERY}{LMC}
\DeclareTextSymbolDefault{\CYRSFTSN}{LMC}
\DeclareTextSymbolDefault{\CYREREV}{LMC}
\DeclareTextSymbolDefault{\CYRYU}{LMC}
\DeclareTextSymbolDefault{\CYRYA}{LMC}
%
\DeclareTextSymbolDefault{\cyra}{LMC}
\DeclareTextSymbolDefault{\cyrb}{LMC}
\DeclareTextSymbolDefault{\cyrv}{LMC}
\DeclareTextSymbolDefault{\cyrg}{LMC}
\DeclareTextSymbolDefault{\cyrd}{LMC}
\DeclareTextSymbolDefault{\cyre}{LMC}
\DeclareTextSymbolDefault{\cyryo}{LMC}
\DeclareTextSymbolDefault{\cyrzh}{LMC}
\DeclareTextSymbolDefault{\cyrz}{LMC}
\DeclareTextSymbolDefault{\cyri}{LMC}
\DeclareTextSymbolDefault{\cyrishrt}{LMC}
\DeclareTextSymbolDefault{\cyrk}{LMC}
\DeclareTextSymbolDefault{\cyrl}{LMC}
\DeclareTextSymbolDefault{\cyrm}{LMC}
\DeclareTextSymbolDefault{\cyrn}{LMC}
\DeclareTextSymbolDefault{\cyro}{LMC}
\DeclareTextSymbolDefault{\cyrotld}{LMC}
\DeclareTextSymbolDefault{\cyrp}{LMC}
\DeclareTextSymbolDefault{\cyrr}{LMC}
\DeclareTextSymbolDefault{\cyrs}{LMC}
\DeclareTextSymbolDefault{\cyrt}{LMC}
\DeclareTextSymbolDefault{\cyru}{LMC}
\DeclareTextSymbolDefault{\cyry}{LMC}
\DeclareTextSymbolDefault{\cyrf}{LMC}
\DeclareTextSymbolDefault{\cyrh}{LMC}
\DeclareTextSymbolDefault{\cyrhsha}{LMC}
\DeclareTextSymbolDefault{\cyrc}{LMC}
\DeclareTextSymbolDefault{\cyrch}{LMC}
\DeclareTextSymbolDefault{\cyrsh}{LMC}
\DeclareTextSymbolDefault{\cyrshch}{LMC}
\DeclareTextSymbolDefault{\cyrhrdsn}{LMC}
\DeclareTextSymbolDefault{\cyrery}{LMC}
\DeclareTextSymbolDefault{\cyrsftsn}{LMC}
\DeclareTextSymbolDefault{\cyrerev}{LMC}
\DeclareTextSymbolDefault{\cyryu}{LMC}
\DeclareTextSymbolDefault{\cyrya}{LMC}
%
\endinput
%% 
%% End of file `lmcenc.def'.
