%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: Russian.tex
%      Author: Oliver Corff
%        Date: June 1st, 1998
%     Version: 0.2
%      Source: Russian.sty
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: Russian captions
%
%        Note: This file draws *HEAVILY* from the file
%              <russian.sty> (numerous authors, see comments)!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
\def\captionsrussian{%
    \def\prefacename   {\xalx{Predislowie}}	%{Orshil}
    \def\refname       {\xalx{Literatura}}	%{Ashiglasan nom}
    \def\abstractname  {\xalx{Annotaciya}}	%{Towqlol}
    \def\bibname       {\xalx{Literatura}}	%{Nom z"u"i}
    \def\chaptername   {\xalx{Glawa}}		%{B"ul"ag}
    \def\appendixname  {\xalx{Prilojenie}}	%{Xawsralt}
    % for books --				%{}
    \def\contentsname  {\xalx{Oglawlenie}}	%{Garqig}
    % for articles etc.--			%{}
    %\def\contentsname  {\xalx{Soderjanie}}	%{Aguulga}
    \def\listfigurename{\xalx{Spisok risunkow}}	%{Zurgi"in jagsaalt}
    \def\listtablename {\xalx{Spisok tablic}}	%{X"usn"agti"in jagsaalt}
    \def\indexname     {\xalx{Predmetny"i ukazatel\i}}	%{B"ugd x"alx"a"as}
    \def\figurename    {\xalx{Ris.}}		%{Zurag}
    \def\tablename     {\xalx{Tablica}}		%{X"usn"agt}
    \def\partname      {\xalx{Qast\i}}		%{B"ul"ag}
    \def\enclname      {\xalx{wkl.}}		%{Oruulax}
    \def\ccname        {\xalx{iz}}		%{}
    \def\headtoname    {\xalx{w}}		%{}
    \def\pagename      {\xalx{str.}}		%{Xuudas}
    \def\seename       {\xalx{sm.}}		%{"Uz}
    \def\alsoname      {\xalx{sm.~takje}}	%{M"on "uz}
}
\def\MonthRussian{\ifcase\month%
	\or yanwarya%	January
	\or fewralya%	February
	\or marta%	March
	\or aprelya%	April
	\or maya%	May
	\or iyunya%	June
	\or iyulya%	July
	\or awgusta%	August
	\or sentyabrya%	September
	\or oktyabrya%	October
	\or noyabrya%	November
	\or dekabrya%	December
	\fi}
\def\RussianToday{{\mnr \number\day~\MonthRussian~\number\year}}

%
\newcommand{\Asbuk}[1]{{\mnr\ifcase#1%
	\or A\or B\or W\or G\or D\or E\or J\or Z%
	\or I\or K\or L\or M\or N\or O\or P\or R%
	\or S\or T\or U\or F\or X\or C\or Q\or {\Sh}%
	\or \Qh\or \"A\or \Yu\or \Ya\else\@ctrerr\fi}}%
%
\newcommand{\asbuk}[1]{{\mnr\ifcase#1%
	\or a\or b\or w\or g\or d\or e\or j\or z%
	\or i\or k\or l\or m\or n\or o\or p\or r%
	\or s\or t\or u\or f\or x\or c\or q\or {\sh}%
	\or \qh\or \"a\or \yu\or \ya\else\@ctrerr\fi}}%
