echo To create tfm\'s for lh-fonts in the KOI-8 encoding we have
echo to determine the proper command which depends on the teTeX version.
echo Trying \"mktextfm\" and \"MakeTeXTFM\" ...
if [ `mktextfm cmr10` ]; then
  MKTFMC=mktextfm
elif [ `MakeTeXTFM cmr10` ]; then
  MKTFMC=MakeTeXTFM
else
  echo Cannot determine a command for creating tfm!
  exit 1
fi       
echo Using \"$MKTFMC\" ...

$MKTFMC kcb10                
$MKTFMC kcbx10               
$MKTFMC kcbx12               
$MKTFMC kcbx5                
$MKTFMC kcbx6                
$MKTFMC kcbx7                
$MKTFMC kcbx8                
$MKTFMC kcbx9                
$MKTFMC kcbxsl10             
$MKTFMC kcbxti10             
$MKTFMC kccsc10              
$MKTFMC kccsc8               
$MKTFMC kccsc9               
$MKTFMC kcdunh10             
$MKTFMC kcff10               
$MKTFMC kcfi10               
$MKTFMC kcfib8               
$MKTFMC kcitt10              
$MKTFMC kcr10                
$MKTFMC kcr12                
$MKTFMC kcr17                
$MKTFMC kcr5                 
$MKTFMC kcr6                 
$MKTFMC kcr7                 
$MKTFMC kcr8                 
$MKTFMC kcr9                 
$MKTFMC kcsl10               
$MKTFMC kcsl12               
$MKTFMC kcsl8                
$MKTFMC kcsl9                
$MKTFMC kcsltt10             
$MKTFMC kcss10               
$MKTFMC kcss12               
$MKTFMC kcss17               
$MKTFMC kcss8                
$MKTFMC kcss9                
$MKTFMC kcssbx10             
$MKTFMC kcssdc10             
$MKTFMC kcssi10              
$MKTFMC kcssi12              
$MKTFMC kcssi17              
$MKTFMC kcssi8               
$MKTFMC kcssi9               
$MKTFMC kcssq8               
$MKTFMC kcssqi8              
$MKTFMC kctcsc10             
$MKTFMC kcti10               
$MKTFMC kcti12               
$MKTFMC kcti7                
$MKTFMC kcti8                
$MKTFMC kcti9                
$MKTFMC kctt10               
$MKTFMC kctt12               
$MKTFMC kctt8                
$MKTFMC kctt9                
$MKTFMC kcu10                
$MKTFMC kcvtt10              























































