%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: lmuenc.def
%      Author: Oliver Corff
%        Date: December 1st, 2001
%     Version: 0.8
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: Local Mongolian Glyph Container Definition
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
%
\ProvidesFile{lmuenc.def}
	[2001/12/01 v0.8 Mongolian Language Support Glyph Container]
%%  %
%%  %
\DeclareFontEncoding{LMU}{}{}{}
\DeclareFontSubstitution{LMU}{bxghs}{m}{n}
%%  %
%%  \DeclareTextComposite{\"}{LMO}{a}{69}
%%  \DeclareTextComposite{\"}{LMO}{o}{79}
%%  \DeclareTextComposite{\"}{LMO}{u}{85}
%%  %
%%  \DeclareTextSymbol{\titem}{LMO}{"40}
%%  \DeclareTextSymbol{\shud}{LMO}{"61}
%%  \DeclareTextSymbol{\secondaryshud}{LMO}{"41}
%%  \DeclareTextSymbol{\shilbe}{LMO}{"69}
%%  \DeclareTextSymbol{\gedes}{LMO}{"6F}
%%  \DeclareTextSymbol{\secondarygedes}{LMO}{"4F}
%%  \DeclareTextSymbol{\cegteishud}{LMO}{"6E}
%%  \DeclareTextSymbol{\lewer}{LMO}{"6C}
%%  \DeclareTextSymbol{\suuliinlewer}{LMO}{"4C}
%%  \DeclareTextSymbol{\tertiarylewer}{LMO}{"51}
%%  \DeclareTextSymbol{\mewer}{LMO}{"6D}
%%  \DeclareTextSymbol{\suuliinmewer}{LMO}{"4D}
%%  \DeclareTextSymbol{\xewteeqix}{LMO}{"78}
%%  \DeclareTextSymbol{\dawxarcegtxewteeqix}{LMO}{"58}
%%  \DeclareTextSymbol{\halfnum}{LMO}{"67}
%%  \DeclareTextSymbol{\num}{LMO}{"49}
%%  \DeclareTextSymbol{\halfnumtgedes}{LMO}{"42}
%%  \DeclareTextSymbol{\numtaigedes}{LMO}{"62}
%%  \DeclareTextSymbol{\buruuxarsangedes}{LMO}{"74}
%%  \DeclareTextSymbol{\gedesteishilbe}{LMO}{"64}
%%  \DeclareTextSymbol{\erweeljinshilbe}{LMO}{"72}
%%  \DeclareTextSymbol{\secerweeljin}{LMO}{"52}
%%  \DeclareTextSymbol{\bosooshilbe}{LMO}{"7A}
%%  \DeclareTextSymbol{\etgershilbe}{LMO}{"79}
%%  \DeclareTextSymbol{\zawj}{LMO}{"73}
%%  \DeclareTextSymbol{\suuliinzawj}{LMO}{"53}
%%  \DeclareTextSymbol{\dawxarcegtzawj}{LMO}{"71}
%%  \DeclareTextSymbol{\sereeewer}{LMO}{"63}
%%  \DeclareTextSymbol{\matgarshilbe}{LMO}{"76}
%%  \DeclareTextSymbol{\bituushilbe}{LMO}{"68}
%%  \DeclareTextSymbol{\secondaryqagt}{LMO}{"4B}
%%  \DeclareTextSymbol{\qagt}{LMO}{"6B}
%%  \DeclareTextSymbol{\secnumtdelbenqix}{LMO}{"50}
%%  \DeclareTextSymbol{\numtdelbenqix}{LMO}{"70}
%%  \DeclareTextSymbol{\secsertenqixtnum}{LMO}{"46}
%%  \DeclareTextSymbol{\sertenqixtnum}{LMO}{"66}
%%  \DeclareTextSymbol{\zadgaizardigt}{LMO}{"5A}
%%  \DeclareTextSymbol{\bituuzardigt}{LMO}{"4C}
%%  \DeclareTextSymbol{\malgaitaititem}{LMO}{"6A}
%%  \DeclareTextSymbol{\suul}{LMO}{"65}
%%  \DeclareTextSymbol{\orxic}{LMO}{"45}
%%  \DeclareTextSymbol{\biodoisuul}{LMO}{"59}
%%  \DeclareTextSymbol{\bagodoisuul}{LMO}{"47}
%%  \DeclareTextSymbol{\nceg}{LMO}{"2D}
%%  \DeclareTextSymbol{\gceg}{LMO}{"3D}
%%  \DeclareTextSymbol{\ceg}{LMO}{"2C}
%%  \DeclareTextSymbol{\dorwoljin}{LMO}{"3B}
%%  
%%  \DeclareTextSymbolDefault{\shud}{LMO}
%%  \DeclareTextSymbolDefault{\secondaryshud}{LMO}
%%  \DeclareTextSymbolDefault{\gedes}{LMO}
%%  \DeclareTextSymbolDefault{\secondarygedes}{LMO}
%%  \DeclareTextSymbolDefault{\shilbe}{LMO}
%%  \DeclareTextSymbolDefault{\cegteishud}{LMO}
%%  \DeclareTextSymbolDefault{\lewer}{LMO}
%%  \DeclareTextSymbolDefault{\suuliinlewer}{LMO}
%%  \DeclareTextSymbolDefault{\tertiarylewer}{LMO}
%%  \DeclareTextSymbolDefault{\mewer}{LMO}
%%  \DeclareTextSymbolDefault{\suuliinmewer}{LMO}
%%  \DeclareTextSymbolDefault{\xewteeqix}{LMO}
%%  \DeclareTextSymbolDefault{\dawxarcegtxewtee}{LMO}
%%  \DeclareTextSymbolDefault{\halfnum}{LMO}
%%  \DeclareTextSymbolDefault{\num}{LMO}
%%  \DeclareTextSymbolDefault{\halfnumtgedes}{LMO}
%%  \DeclareTextSymbolDefault{\numtoigedes}{LMO}
%%  \DeclareTextSymbolDefault{\buruuxarsangedes}{LMO}
%%  \DeclareTextSymbolDefault{\gedesteishilbe}{LMO}
%%  \DeclareTextSymbolDefault{\erweeljinshilbe}{LMO}
%%  \DeclareTextSymbolDefault{\secerweeljin}{LMO}
%%  \DeclareTextSymbolDefault{\bosooshilbe}{LMO}
%%  \DeclareTextSymbolDefault{\etgershilbe}{LMO}
%%  \DeclareTextSymbolDefault{\zawj}{LMO}
%%  \DeclareTextSymbolDefault{\suuliinzawj}{LMO}
%%  \DeclareTextSymbolDefault{\dawxarcegtzawj}{LMO}
%%  \DeclareTextSymbolDefault{\sereeewer}{LMO}
%%  \DeclareTextSymbolDefault{\matgarshilbe}{LMO}
%%  \DeclareTextSymbolDefault{\bituushilbe}{LMO}
%%  \DeclareTextSymbolDefault{\secondaryqagt}{LMO}
%%  \DeclareTextSymbolDefault{\qagt}{LMO}
%%  \DeclareTextSymbolDefault{\secnumtdelbenq}{LMO}
%%  \DeclareTextSymbolDefault{\numtdelbenqix}{LMO}
%%  \DeclareTextSymbolDefault{\secsertenqixt}{LMO}
%%  \DeclareTextSymbolDefault{\sertenqixtnum}{LMO}
%%  \DeclareTextSymbolDefault{\zadgaizardigt}{LMO}
%%  \DeclareTextSymbolDefault{\bituuzardigt}{LMO}
%%  \DeclareTextSymbolDefault{\malgaitaititem}{LMO}
%%  \DeclareTextSymbolDefault{\suul}{LMO}
%%  \DeclareTextSymbolDefault{\orxic}{LMO}
%%  \DeclareTextSymbolDefault{\biodoisuul}{LMO}
%%  \DeclareTextSymbolDefault{\bagodoisuul}{LMO}
%%  \DeclareTextSymbolDefault{\nceg}{LMO}
%%  \DeclareTextSymbolDefault{\gceg}{LMO}
%%  \DeclareTextSymbolDefault{\ceg}{LMO}
%%  \DeclareTextSymbolDefault{\dorwoljin}{LMO}
%
\endinput
