%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: cpncc.def
%      Author: Oliver Corff
%        Date: February 8th, 1998
%     Version: 0.3
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: NCC codepage definition
%
%        Note: This file forms part of the MonTeX package which
%              should always be distributed in complete form.
%
%              The code positions in this file were cross-checked
%              by Vladimir Volovich and are compatible in position
%              and name with those of the emerging T2 standard.
%
%              Thank you very much, Vladimir!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
\ProvidesFile{cpncc.def}
   [1997/11/01 v0.1 Input encoding file for NCC encoding]
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
%
% Cyrillic Letters
%
\DeclareInputText{128}{\CYRA}
\DeclareInputText{129}{\CYRB}
\DeclareInputText{130}{\CYRV}
\DeclareInputText{131}{\CYRG}
\DeclareInputText{132}{\CYRD}
\DeclareInputText{133}{\CYRE}
\DeclareInputText{134}{\CYRYO}
\DeclareInputText{135}{\CYRZH}
\DeclareInputText{136}{\CYRZ}
\DeclareInputText{137}{\CYRI}
\DeclareInputText{139}{\CYRISHRT}
\DeclareInputText{140}{\CYRK}
\DeclareInputText{142}{\CYRL}
\DeclareInputText{143}{\CYRM}
\DeclareInputText{144}{\CYRN}
\DeclareInputText{145}{\CYRO}
\DeclareInputText{146}{\CYROTLD}
\DeclareInputText{147}{\CYRP}
\DeclareInputText{148}{\CYRR}
\DeclareInputText{149}{\CYRS}
\DeclareInputText{150}{\CYRT}
\DeclareInputText{151}{\CYRU}
\DeclareInputText{152}{\CYRY}
\DeclareInputText{153}{\CYRF}
\DeclareInputText{154}{\CYRH}
\DeclareInputText{155}{\CYRC}
\DeclareInputText{156}{\CYRCH}
\DeclareInputText{157}{\CYRSH}
\DeclareInputText{158}{\CYRSHCH}
\DeclareInputText{159}{\CYRHRDSN}
\DeclareInputText{160}{\CYRERY}
\DeclareInputText{161}{\CYRSFTSN}
\DeclareInputText{162}{\CYREREV}
\DeclareInputText{163}{\CYRYU}
\DeclareInputText{164}{\CYRYA}
\DeclareInputText{165}{\cyra}
\DeclareInputText{166}{\cyrb}
\DeclareInputText{167}{\cyrv}
\DeclareInputText{168}{\cyrg}
\DeclareInputText{169}{\cyrd}
\DeclareInputText{170}{\cyre}
\DeclareInputText{171}{\cyryo}
\DeclareInputText{172}{\cyrzh}
\DeclareInputText{173}{\cyrz}
\DeclareInputText{225}{\cyri}
\DeclareInputText{226}{\cyrishrt}
\DeclareInputText{227}{\cyrk}
\DeclareInputText{228}{\cyrl}
\DeclareInputText{229}{\cyrm}
\DeclareInputText{230}{\cyrn}
\DeclareInputText{231}{\cyro}
\DeclareInputText{232}{\cyrotld}
\DeclareInputText{233}{\cyrp}
\DeclareInputText{234}{\cyrr}
\DeclareInputText{235}{\cyrs}
\DeclareInputText{236}{\cyrt}
\DeclareInputText{237}{\cyru}
\DeclareInputText{238}{\cyry}
\DeclareInputText{239}{\cyrf}
\DeclareInputText{240}{\cyrh}
\DeclareInputText{241}{\cyrc}
\DeclareInputText{242}{\cyrch}
\DeclareInputText{243}{\cyrsh}
\DeclareInputText{244}{\cyrshch}
\DeclareInputText{245}{\cyrhrdsn}
\DeclareInputText{246}{\cyrery}
\DeclareInputText{247}{\cyrsftsn}
\DeclareInputText{248}{\cyrerev}
\DeclareInputText{249}{\cyryu}
\DeclareInputText{251}{\cyrya}
%
\endinput
%% 
%% End of file `cpncc.def'.
