%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: Buryat.def
%      Author: Oliver Corff
%        Date: June 1st, 1998
%     Version: 0.2
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: Conventional Labels and litteral date,
%	       given in Buryat
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
%
% The caption names are defined here.
%
\def\captionsburyat{%
	\def\prefacename	{{\mnr Orshol}}
	\def\refname		{{\mnr A{\sh}aglahan nom}}
	\def\abstractname	{{\mnr Tob{\sh}olol}}
	\def\bibname		{{\mnr Nom z"u"i}}
	\def\chaptername	{{\mnr B"ul"ag}}
	\def\appendixname	{{\mnr Xabsaralta}}
	\def\contentsname	{{\mnr Gar{\sh}ag}}
	%\def\contentsname	{{\mnr Aguulga}}
	\def\listfigurename	{{\mnr Zuraga"i jagsaalt}}
	\def\listtablename	{{\mnr X"usn"ag"at"a"i jagsaalt}}
	\def\indexname		{{\mnr B"ug"ad x"alx"a"as}}
	\def\figurename		{{\mnr Zurag}}
	\def\tablename		{{\mnr X"us"an"agt}}
	\def\partname		{{\mnr B"ul"ag}}
	\def\enclname		{{\mnr Oruulaxa}}
	\def\ccname		{{\mnr }}
	\def\headtoname		{{\mnr }}
	\def\pagename		{{\mnr Xuudahan}}
	\def\seename		{{\mnr "Uz}}
	\def\alsoname		{{\mnr M"un "uz}}%
}
\newcommand{\BuryatToday}{%
{\mnr\number\year\space ono"i\space\ifcase\month%
		\or yanwariin			% Januar
		\or fewraliin			% Februar
		\or martyn			% M"arz
		\or apreliin			% April
		\or ma"in			% Mai
		\or iyuniin			% Juni
		\or iyuliin			% Juli
		\or awgustyn			% August
		\or centyabriin			% September
		\or oktyabriin			% Oktober
		\or noyabriin			% November
		\or dekyabriin\fi		% Dezember
	\space\number\day\ifcase\day%
		\or -n"a"i	% 01
		\or -o"i	% 02
		\or -na"i	% 03
		\or -n"a"i	% 04
		\or -na"i	% 05
		\or -na"i	% 06
		\or -no"i	% 07
		\or -na"i	% 08
		\or -n"a"i	% 09
		\or -na"i	% 10
		\or -n"a"i	% 11
		\or -o"i	% 12
		\or -na"i	% 13
		\or -n"a"i	% 14
		\or -na"i	% 15
		\or -na"i	% 16
		\or -no"i	% 17
		\or -na"i	% 18
		\or -n"a"i	% 19
		\or -no"i	% 20
		\or -n"a"i	% 21
		\or -o"i	% 22
		\or -na"i	% 23
		\or -n"a"i	% 24
		\or -na"i	% 25
		\or -na"i	% 26
		\or -no"i	% 27
		\or -na"i	% 28
		\or -n"a"i	% 29
		\or -na"i	% 30
		\or -n"a"i\fi	% 31
	\space "ud"ar}}
%
\newcommand{\Uzeg}[1]{{\mnr\ifcase#1%
	\or A\or B\or W\or G\or D\or E\or \"E\or J%
	\or Z\or I\or K\or L\or M\or N\or O\or \"O%
	\or P\or R\or S\or T\or U\or \"U\or F\or X%
	\or H\or C\or Q\or {\Sh}\or \Qh\or \"A\or \Yu\or \Ya%
		\else\@ctrerr\fi}}%
%
\newcommand{\uzeg}[1]{{\mnr\ifcase#1%
	\or a\or b\or w\or g\or d\or e\or \"e\or j%
	\or z\or i\or k\or l\or m\or n\or o\or \"o%
	\or p\or r\or s\or t\or u\or \"u\or f\or x%
	\or h\or c\or q\or {\sh}\or \qh\or \"a\or \yu\or \ya%
		\else\@ctrerr\fi}}%
%
% Buryat Captions end here.
%
% Some options are not yet completely implemented so
% we include some code for activating/deactivating
% the relevant documentation in montex.tex
%
% 0 indicates absence, 1 indicates presence of an
% ifthenelse option.
%
\newcounter{BuryatAvailable}
\setcounter{BuryatAvailable}{1}
%
