%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: cpibmrus.def
%      Author: Oliver Corff
%        Date: November 8th, 2001
%     Version: 0.4
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: IBMRUS codepage definition
%
%        Note: This file forms part of the MonTeX package which
%              should always be distributed in complete form.
%
%              The code positions in this file were cross-checked
%              by Vladimir Volovich and are compatible in position
%              and name with those of the T2 standard.
%
%              Thank you very much, Vladimir!
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
\ProvidesFile{cpibmrus.def}
   [1997/11/01 v0.1 Input encoding file for IBM RUS encoding]
\NeedsTeXFormat{LaTeX2e}[1995/12/01]
%
% Cyrillic Letters
%
\DeclareInputText{"80}{\CYRA}
\DeclareInputText{"81}{\CYRB}
\DeclareInputText{"82}{\CYRV}
\DeclareInputText{"83}{\CYRG}
\DeclareInputText{"84}{\CYRD}
\DeclareInputText{"85}{\CYRE}
\DeclareInputText{"F0}{\CYRYO}
\DeclareInputText{"86}{\CYRZH}
\DeclareInputText{"87}{\CYRZ}
\DeclareInputText{"88}{\CYRI}
\DeclareInputText{"89}{\CYRISHRT}
\DeclareInputText{"8A}{\CYRK}
\DeclareInputText{"8B}{\CYRL}
\DeclareInputText{"8C}{\CYRM}
\DeclareInputText{"8D}{\CYRN}
\DeclareInputText{"8E}{\CYRO}
% \DeclareInputText{"  }{\CYROTLD} Not available in IBM RUS!
\DeclareInputText{"8F}{\CYRP}
\DeclareInputText{"90}{\CYRR}
\DeclareInputText{"91}{\CYRS}
\DeclareInputText{"92}{\CYRT}
\DeclareInputText{"93}{\CYRU}
% \DeclareInputText{"  }{\CYRY} Not available in IBM RUS!
\DeclareInputText{"94}{\CYRF}
\DeclareInputText{"95}{\CYRH}
\DeclareInputText{"96}{\CYRC}
\DeclareInputText{"97}{\CYRCH}
\DeclareInputText{"98}{\CYRSH}
\DeclareInputText{"99}{\CYRCHSH}
\DeclareInputText{"9A}{\CYRHRDSN}
\DeclareInputText{"9B}{\CYRERY}
\DeclareInputText{"9C}{\CYRSFTSN}
\DeclareInputText{"9D}{\CYREREV}
\DeclareInputText{"9E}{\CYRYU}
\DeclareInputText{"9F}{\CYRYA}

\DeclareInputText{"A0}{\cyra}
\DeclareInputText{"A1}{\cyrb}
\DeclareInputText{"A2}{\cyrv}
\DeclareInputText{"A3}{\cyrg}
\DeclareInputText{"A4}{\cyrd}
\DeclareInputText{"A5}{\cyre}
\DeclareInputText{"F1}{\cyryo}
\DeclareInputText{"A6}{\cyrzh}
\DeclareInputText{"A7}{\cyrz}
\DeclareInputText{"A8}{\cyri}
\DeclareInputText{"A9}{\cyrishrt}
\DeclareInputText{"AA}{\cyrk}
\DeclareInputText{"AB}{\cyrl}
\DeclareInputText{"AC}{\cyrm}
\DeclareInputText{"AD}{\cyrn}
\DeclareInputText{"AE}{\cyro}
% \DeclareInputText{"  }{\cyrotld} Not available in IBM RUS!
\DeclareInputText{"AF}{\cyrp}
\DeclareInputText{"E0}{\cyrr}
\DeclareInputText{"E1}{\cyrs}
\DeclareInputText{"E2}{\cyrt}
\DeclareInputText{"E3}{\cyru}
% \DeclareInputText{"  }{\cyry} Not available in IBM RUS!
\DeclareInputText{"E4}{\cyrf}
\DeclareInputText{"E5}{\cyrh}
\DeclareInputText{"E6}{\cyrc}
\DeclareInputText{"E7}{\cyrch}
\DeclareInputText{"E8}{\cyrsh}
\DeclareInputText{"E9}{\cyrshch}
\DeclareInputText{"EA}{\cyrhrdsn}
\DeclareInputText{"EB}{\cyrery}
\DeclareInputText{"EC}{\cyrsftsn}
\DeclareInputText{"ED}{\cyrerev}
\DeclareInputText{"EE}{\cyryu}
\DeclareInputText{"EF}{\cyrya}
%
\endinput
%% 
%% End of file `cpibmrus.def'.
