%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: lmoenc.def
%      Author: Oliver Corff
%        Date: July 1st, 2002
%     Version: 0.9
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: Local Mongolian Bicig Encoding Definition
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
%
\ProvidesFile{lmoenc.def}
	[2002/07/01 v0.9 Mongolian Language Support Bicig Encoding]
%%  %
%%  %
\DeclareFontEncoding{LMO}{}{}{}
\DeclareFontSubstitution{LMO}{bcgvs}{m}{n}
%%  %
%%  \DeclareTextComposite{\"}{LMO}{a}{69}
%%  \DeclareTextComposite{\"}{LMO}{o}{79}
%%  \DeclareTextComposite{\"}{LMO}{u}{85}
%
%
%%  \DeclareTextSymbol{\textmongolianbirga}{LMO}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianellipsis}{LMO}{47}
	\DeclareTextSymbolDefault{\textmongolianellipsis}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliancomma}{LMO}{44}
	\DeclareTextSymbolDefault{\textmongoliancomma}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfullstop}{LMO}{46}
	\DeclareTextSymbolDefault{\textmongolianfullstop}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliancolon}{LMO}{58}
	\DeclareTextSymbolDefault{\textmongoliancolon}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfourdots}{LMO}{59}
	\DeclareTextSymbolDefault{\textmongolianfourdots}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongoliantodosofthyphen}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibesyllableboundarymarker}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchucomma}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchufullstop}{LMO}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliannirugu}{LMO}{124}
	\DeclareTextSymbolDefault{\textmongoliannirugu}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfreevariationselectorone}{LMO}{39}
	\DeclareTextSymbolDefault{\textmongolianfreevariationselectorone}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfreevariationselectortwo}{LMO}{34}
	\DeclareTextSymbolDefault{\textmongolianfreevariationselectortwo}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongolianfreevariationselectorthree}{LMO}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianvowelseparator}{LMO}{61}
	\DeclareTextSymbolDefault{\textmongolianvowelseparator}{LMO}
%
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianzero}{LMO}{48}
	\DeclareTextSymbolDefault{\textmongolianzero}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianone}{LMO}{49}
	\DeclareTextSymbolDefault{\textmongolianone}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliantwo}{LMO}{50}
	\DeclareTextSymbolDefault{\textmongoliantwo}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianthree}{LMO}{51}
	\DeclareTextSymbolDefault{\textmongolianthree}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfour}{LMO}{52}
	\DeclareTextSymbolDefault{\textmongolianfour}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfive}{LMO}{53}
	\DeclareTextSymbolDefault{\textmongolianfive}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansix}{LMO}{54}
	\DeclareTextSymbolDefault{\textmongoliansix}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianseven}{LMO}{55}
	\DeclareTextSymbolDefault{\textmongolianseven}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianeight}{LMO}{56}
	\DeclareTextSymbolDefault{\textmongolianeight}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliannine}{LMO}{57}
	\DeclareTextSymbolDefault{\textmongoliannine}{LMO}
%
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliana}{LMO}{97}
	\DeclareTextSymbolDefault{\textmongoliana}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliane}{LMO}{101}
	\DeclareTextSymbolDefault{\textmongoliane}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliani}{LMO}{105}
	\DeclareTextSymbolDefault{\textmongoliani}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliano}{LMO}{117}
	\DeclareTextSymbolDefault{\textmongoliano}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianu}{LMO}{117}
	\DeclareTextSymbolDefault{\textmongolianu}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongolianoe}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianue}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianee}{LMO}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianna}{LMO}{110}
	\DeclareTextSymbolDefault{\textmongolianna}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianang}{LMO}{134}
	\DeclareTextSymbolDefault{\textmongolianang}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianba}{LMO}{98}
	\DeclareTextSymbolDefault{\textmongolianba}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianpa}{LMO}{112}
	\DeclareTextSymbolDefault{\textmongolianpa}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianqa}{LMO}{120}
	\DeclareTextSymbolDefault{\textmongolianqa}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianga}{LMO}{103}
	\DeclareTextSymbolDefault{\textmongolianga}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianma}{LMO}{109}
	\DeclareTextSymbolDefault{\textmongolianma}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianla}{LMO}{108}
	\DeclareTextSymbolDefault{\textmongolianla}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansa}{LMO}{115}
	\DeclareTextSymbolDefault{\textmongoliansa}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansha}{LMO}{160}
	\DeclareTextSymbolDefault{\textmongoliansha}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianta}{LMO}{116}
	\DeclareTextSymbolDefault{\textmongolianta}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianda}{LMO}{100}
	\DeclareTextSymbolDefault{\textmongolianda}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliancha}{LMO}{99}
	\DeclareTextSymbolDefault{\textmongoliancha}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianja}{LMO}{122}
	\DeclareTextSymbolDefault{\textmongolianja}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianya}{LMO}{121}
	\DeclareTextSymbolDefault{\textmongolianya}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianra}{LMO}{114}
	\DeclareTextSymbolDefault{\textmongolianra}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianwa}{LMO}{118}
	\DeclareTextSymbolDefault{\textmongolianwa}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfa}{LMO}{102}
	\DeclareTextSymbolDefault{\textmongolianfa}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianka}{LMO}{113}
	\DeclareTextSymbolDefault{\textmongolianka}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliankha}{LMO}{75}
	\DeclareTextSymbolDefault{\textmongoliankha}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliantsa}{LMO}{67}
	\DeclareTextSymbolDefault{\textmongoliantsa}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianza}{LMO}{90}
	\DeclareTextSymbolDefault{\textmongolianza}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianhaa}{LMO}{104}
	\DeclareTextSymbolDefault{\textmongolianhaa}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianzra}{LMO}{106}
	\DeclareTextSymbolDefault{\textmongolianzra}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\def\textmongolianlha{\textmongolianla\textmongolianhaa}
%%	\DeclareTextSymbolDefault{\textmongolianlha}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongolianzhi}{LMO}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\def\textmongolianzhi{*\textmongolianhaa}
\def\textmongolianchi{*\textmongolianu\textmongolianu}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongolianchi}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodolongvowelsign}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoe}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoi}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoo}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodou}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodooe}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoue}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoang}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoba}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodopa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoqa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoga}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoma}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodota}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantododa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodocha}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoja}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodotsa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoya}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodowa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoka}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodogaa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodohaa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodojia}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodonia}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantododza}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibee}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibei}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibeiy}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibeue}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibeu}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibeang}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibeka}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibega}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibeha}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibepa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibesha}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibeta}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibeda}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibeja}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibefa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibegaa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibehaa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibetsa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibeza}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansiberaa}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibecha}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliansibezha}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchui}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchuka}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchura}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchufa}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchuzha}{LMO}{}
%
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianaligalianusvaraone}{LMO}{96}
	\DeclareTextSymbolDefault{\textmongolianaligalianusvaraone}{LMO}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%
%%  \DeclareTextSymbol{\textmongolianaligalivisargaone}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalidamaru}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligaliubadama}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligaliinvertedubadama}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalibaluda}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalithreebaluda}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalia}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalii}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalika}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalinga}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalica}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalitta}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalittha}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalidda}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalinna}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalita}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalida}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalipa}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalipha}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalissa}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalizha}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligaliza}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligaliah}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoaligalita}{LMO}{}
%%  \DeclareTextSymbol{\textmongoliantodoaligalizha}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigaligha}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigalinga}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigalica}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigalijha}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigalitta}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigaliddha}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigalita}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigalidha}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigalissa}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigalicya}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigalizha}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigaliza}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalihalfu}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalihalfya}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianmanchualigalibha}{LMO}{}
%%  \DeclareTextSymbol{\textmongolianaligalidagalga}{LMO}{}
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\endinput
