%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: English.def
%      Author: Oliver Corff
%        Date: November 1st, 1997
%     Version: 0.1
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: Conventional Labels, given in English
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
% We tell what we need and who we are:
%
% The caption names are defined here.
%
\def\captionsenglish{%
\def\prefacename   {Preface}%
\def\refname       {References}%
\def\abstractname  {Abstract}%
\def\bibname       {Bibliography}%
\def\chaptername   {Chapter}%
\def\appendixname  {Appendix}%
\def\contentsname  {Contents}%
\def\listfigurename{List of Figures}%
\def\listtablename {List of Tables}%
\def\indexname     {Index}%
\def\figurename    {Figure}%
\def\tablename     {Table}%
\def\partname      {Part}%
\def\enclname      {encl}%
\def\ccname        {cc}%
\def\headtoname    {To}%
\def\pagename      {Page}%
\def\seename       {see}%
\def\alsoname      {see also}}
