%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%        File: lmaenc.def
%      Author: Oliver Corff
%        Date: July 1st, 2002
%     Version: 0.9
%   Copyright: Ulaanbaatar, Beijing, Berlin
%
% Description: Local Manju Bithe Encoding Definition
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% -------------------     identification     -------------------
%
\ProvidesFile{lmaenc.def}
	[2002/07/01 v0.9 Manju Language Support Bithe Encoding]
%
%
\DeclareFontEncoding{LMA}{}{}
\DeclareFontSubstitution{LMA}{bthvs}{m}{n}
%
\DeclareTextComposite{\^}{LMA}{u}{69}
\DeclareTextComposite{\v}{LMA}{s}{79}
%
%%  \DeclareTextSymbol{\textmongolianbirga}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianellipsis}{LMA}{47}
	\DeclareTextSymbolDefault{\textmongolianellipsis}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongoliancomma}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianfullstop}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliancolon}{LMA}{58}
	\DeclareTextSymbolDefault{\textmongoliancolon}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfourdots}{LMA}{59}
	\DeclareTextSymbolDefault{\textmongolianfourdots}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongoliantodosofthyphen}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliansibesyllableboundarymarker}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianmanchucomma}{LMA}{44}
	\DeclareTextSymbolDefault{\textmongolianmanchucomma}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianmanchufullstop}{LMA}{46}
	\DeclareTextSymbolDefault{\textmongolianmanchufullstop}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliannirugu}{LMA}{124}
	\DeclareTextSymbolDefault{\textmongoliannirugu}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfreevariationselectorone}{LMA}{39}
	\DeclareTextSymbolDefault{\textmongolianfreevariationselectorone}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfreevariationselectortwo}{LMA}{34}
	\DeclareTextSymbolDefault{\textmongolianfreevariationselectortwo}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongolianfreevariationselectorthree}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianvowelseparator}{LMA}{43}
	\DeclareTextSymbolDefault{\textmongolianvowelseparator}{LMA}
%
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianzero}{LMA}{48}
	\DeclareTextSymbolDefault{\textmongolianzero}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianone}{LMA}{49}
	\DeclareTextSymbolDefault{\textmongolianone}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliantwo}{LMA}{50}
	\DeclareTextSymbolDefault{\textmongoliantwo}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianthree}{LMA}{51}
	\DeclareTextSymbolDefault{\textmongolianthree}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfour}{LMA}{52}
	\DeclareTextSymbolDefault{\textmongolianfour}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianfive}{LMA}{53}
	\DeclareTextSymbolDefault{\textmongolianfive}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansix}{LMA}{54}
	\DeclareTextSymbolDefault{\textmongoliansix}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianseven}{LMA}{55}
	\DeclareTextSymbolDefault{\textmongolianseven}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianeight}{LMA}{56}
	\DeclareTextSymbolDefault{\textmongolianeight}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliannine}{LMA}{57}
	\DeclareTextSymbolDefault{\textmongoliannine}{LMA}
%
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliana}{LMA}{97}
	\DeclareTextSymbolDefault{\textmongoliana}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongoliane}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliani}{LMA}{105}
	\DeclareTextSymbolDefault{\textmongoliani}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliano}{LMA}{111}
	\DeclareTextSymbolDefault{\textmongoliano}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongolianu}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianoe}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianue}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianee}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianna}{LMA}{110}
	\DeclareTextSymbolDefault{\textmongolianna}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongolianang}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianba}{LMA}{98}
	\DeclareTextSymbolDefault{\textmongolianba}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongolianpa}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianqa}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianga}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianma}{LMA}{109}
	\DeclareTextSymbolDefault{\textmongolianma}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianla}{LMA}{108}
	\DeclareTextSymbolDefault{\textmongolianla}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansa}{LMA}{115}
	\DeclareTextSymbolDefault{\textmongoliansa}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongoliansha}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianta}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianda}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliancha}{LMA}{99}
	\DeclareTextSymbolDefault{\textmongoliancha}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianja}{LMA}{106}
	\DeclareTextSymbolDefault{\textmongolianja}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianya}{LMA}{121}
	\DeclareTextSymbolDefault{\textmongolianya}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongolianra}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianwa}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianfa}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianka}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliankha}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantsa}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianza}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianhaa}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianzra}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianlha}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianzhi}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianchi}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodolongvowelsign}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoe}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoi}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoo}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodou}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodooe}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoue}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoang}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoba}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodopa}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoqa}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoga}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoma}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodota}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantododa}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodocha}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoja}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodotsa}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoya}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodowa}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoka}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodogaa}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodohaa}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodojia}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodonia}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantododza}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibee}{LMA}{101}
	\DeclareTextSymbolDefault{\textmongoliansibee}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%%%  \DeclareTextSymbol{\textmongoliansibei}{LMA}{105}
%%  \DeclareTextSymbol{\textmongoliansibeiy}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibeue}{LMA}{117}
	\DeclareTextSymbolDefault{\textmongoliansibeue}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibeu}{LMA}{118}
	\DeclareTextSymbolDefault{\textmongoliansibeu}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibeang}{LMA}{134}
	\DeclareTextSymbolDefault{\textmongoliansibeang}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%%%  \DeclareTextSymbol{\textmongoliansibeka}{LMA}{107}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibega}{LMA}{103}
	\DeclareTextSymbolDefault{\textmongoliansibega}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibeha}{LMA}{104}
	\DeclareTextSymbolDefault{\textmongoliansibeha}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibepa}{LMA}{112}
	\DeclareTextSymbolDefault{\textmongoliansibepa}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibesha}{LMA}{159}
	\DeclareTextSymbolDefault{\textmongoliansibesha}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibeta}{LMA}{116}
	\DeclareTextSymbolDefault{\textmongoliansibeta}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibeda}{LMA}{100}
	\DeclareTextSymbolDefault{\textmongoliansibeda}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%%%  \DeclareTextSymbol{\textmongoliansibeja}{LMA}{}
%%%%  \DeclareTextSymbol{\textmongoliansibefa}{LMA}{102}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibegaa}{LMA}{162}
	\DeclareTextSymbolDefault{\textmongoliansibegaa}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibehaa}{LMA}{163}
	\DeclareTextSymbolDefault{\textmongoliansibehaa}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibetsa}{LMA}{177}
	\DeclareTextSymbolDefault{\textmongoliansibetsa}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibeza}{LMA}{165}
	\DeclareTextSymbolDefault{\textmongoliansibeza}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansiberaa}{LMA}{183}
	\DeclareTextSymbolDefault{\textmongoliansiberaa}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongoliansibecha}{LMA}{174}
	\DeclareTextSymbolDefault{\textmongoliansibecha}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%%%  \DeclareTextSymbol{\textmongoliansibezha}{LMA}{174}
%%%%  \DeclareTextSymbol{\textmongolianmanchui}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianmanchuka}{LMA}{107}
	\DeclareTextSymbolDefault{\textmongolianmanchuka}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianmanchura}{LMA}{114}
	\DeclareTextSymbolDefault{\textmongolianmanchura}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianmanchufa}{LMA}{102}
	\DeclareTextSymbolDefault{\textmongolianmanchufa}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianmanchuzha}{LMA}{119}
	\DeclareTextSymbolDefault{\textmongolianmanchuzha}{LMA}
%
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%  \DeclareTextSymbol{\textmongolianaligalianusvaraone}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalivisargaone}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalidamaru}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligaliubadama}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligaliinvertedubadama}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalibaluda}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalithreebaluda}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalia}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalii}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalika}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalinga}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalica}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalitta}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalittha}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalidda}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalinna}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalita}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalida}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalipa}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalipha}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalissa}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligalizha}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligaliza}{LMA}{}
%%  \DeclareTextSymbol{\textmongolianaligaliah}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoaligalita}{LMA}{}
%%  \DeclareTextSymbol{\textmongoliantodoaligalizha}{LMA}{}
%%%%  \DeclareTextSymbol{\textmongolianmanchualigaligha}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianmanchualigalinga}{LMA}{185}
	\DeclareTextSymbolDefault{\textmongolianmanchualigalinga}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianmanchualigalica}{LMA}{175}
	\DeclareTextSymbolDefault{\textmongolianmanchualigalica}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%%%  \DeclareTextSymbol{\textmongolianmanchualigalijha}{LMA}{}
%%%%  \DeclareTextSymbol{\textmongolianmanchualigalitta}{LMA}{}
%%%%  \DeclareTextSymbol{\textmongolianmanchualigaliddha}{LMA}{}
%%%%  \DeclareTextSymbol{\textmongolianmanchualigalita}{LMA}{}
%%%%  \DeclareTextSymbol{\textmongolianmanchualigalidha}{LMA}{}
%%%%  \DeclareTextSymbol{\textmongolianmanchualigalissa}{LMA}{}
%%%%  \DeclareTextSymbol{\textmongolianmanchualigalicya}{LMA}{}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianmanchualigalizha}{LMA}{181}
	\DeclareTextSymbolDefault{\textmongolianmanchualigalizha}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
\DeclareTextSymbol{\textmongolianmanchualigaliza}{LMA}{122}
	\DeclareTextSymbolDefault{\textmongolianmanchualigaliza}{LMA}
% % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % % %
%%%%  \DeclareTextSymbol{\textmongolianaligalihalfu}{LMA}{}
%%%%  \DeclareTextSymbol{\textmongolianaligalihalfya}{LMA}{}
%%%%  \DeclareTextSymbol{\textmongolianmanchualigalibha}{LMA}{}
%%%%  \DeclareTextSymbol{\textmongolianaligalidagalga}{LMA}{}
\endinput
